@@ -66,7 +66,7 @@ b,,
 >>> print n.get_octave_notename()
 b,,
 >>> print n.get_user_octave_notename()
-<sub>2</sub>H
+<sub>1</sub>H
 >>> print n.get_user_notename()
 h
 >>> print _("Close")
@@ -79,7 +79,7 @@ if __name__ == "__main__":
     import i18n
     i18n.setup_srcdir()
 
-import types, random
+import random
 import _exceptions
 
 # The following are here so that the strings are catched by pygettext
@@ -124,7 +124,7 @@ class InvalidNotenameException(_exceptions.MpdException):
         _exceptions.MpdException.__init__(self)
         self.m_notename = n
     def __str__(self):
-        return "Invalid notename: %s" % self.m_notename
+        return _("Invalid notename: %s") % self.m_notename
 
 class MusicalPitch:
     LOWEST_STEPS = -28
@@ -136,7 +136,7 @@ class MusicalPitch:
         r.m_accidental_i = self.m_accidental_i
         return r
     def new_from_notename(n):
-        assert type(n) in types.StringTypes
+        assert isinstance(n, basestring)
         r = MusicalPitch()
         r.set_from_notename(n)
         return r
@@ -170,6 +170,8 @@ class MusicalPitch:
         elif self.semitone_pitch()-old_p > tra:
             self.m_accidental_i = self.m_accidental_i - 1
         return self
+    def set_from_steps(self, steps):
+        print "x:", 6-(steps % 7) 
     def steps(self):
         return self.m_notename_i + self.m_octave_i * 7
     def semitone_pitch(self):
@@ -203,15 +205,15 @@ class MusicalPitch:
         try:
             self.m_notename_i = ['c', 'd', 'e', 'f', 'g', 'a', 'b'].index(notename)
         except ValueError:
-           raise InvalidNotenameException(tmp)
+            raise InvalidNotenameException(tmp)
     def randomize(self, lowest, highest):
         """
         lowest and highest can be an integer, string or a MusicalPitch instance
         """
         assert type(lowest) == type(highest)
-        if type(lowest) in  types.StringTypes:
+        if isinstance(lowest, basestring):
             lowest = MusicalPitch.new_from_notename(lowest).semitone_pitch()
-        if type(highest) in types.StringTypes:
+        if isinstance(highest, basestring):
             highest = MusicalPitch.new_from_notename(highest).semitone_pitch()
         self.set_from_int(random.randint(int(lowest), int(highest)))
         return self
@@ -236,17 +238,17 @@ class MusicalPitch:
             r.m_accidental_i = r.m_accidental_i + (i.get_intvalue() - _diff)
             # to avoid notenames like ciscisciscis :
             if r.m_accidental_i > 2:
-               r.m_accidental_i = r.m_accidental_i - 2
-               r.m_notename_i = r.m_notename_i + 1
-               if r.m_notename_i == 7:
-                   r.m_notename_i = 0
-                   r.m_octave_i = r.m_octave_i + 1
+                r.m_accidental_i = r.m_accidental_i - 2
+                r.m_notename_i = r.m_notename_i + 1
+                if r.m_notename_i == 7:
+                    r.m_notename_i = 0
+                    r.m_octave_i = r.m_octave_i + 1
             if r.m_accidental_i < -2:
-               r.m_accidental_i = r.m_accidental_i + 2
-               r.m_notename_i = r.m_notename_i - 1
-               if r.m_notename_i == -1:
-                   r.m_notename_i = 6
-                   r.m_octave_i = r.m_octave_i - 1
+                r.m_accidental_i = r.m_accidental_i + 2
+                r.m_notename_i = r.m_notename_i - 1
+                if r.m_notename_i == -1:
+                    r.m_notename_i = 6
+                    r.m_octave_i = r.m_octave_i - 1
             return r
         else:
             raise _exceptions.MpdException("Cannot add %s" %type(i))
@@ -257,7 +259,7 @@ class MusicalPitch:
         """
         if isinstance(i, MusicalPitch):
             return self.semitone_pitch() - i.semitone_pitch()
-        assert type(i) == types.IntType
+        assert isinstance(i, int)
         v = self.semitone_pitch()
         assert 0 <= v - i < 128
         return MusicalPitch.new_from_int(v-i)
