@@ -16,6 +16,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import gtk
+import gobject
 import soundcard
 import parser
 import engravers
@@ -36,7 +37,7 @@ class MusicDisplayer(gtk.ScrolledWindow):
 
         self.add_with_viewport(self.g_d)
         self.g_d.connect("expose_event", self.on_expose_event)
-        self.g_d.add_events(gtk.gdk.EXPOSURE_MASK | gtk.gdk.BUTTON_PRESS_MASK)
+        self.g_d.add_events(gtk.gdk.EXPOSURE_MASK | gtk.gdk.BUTTON_RELEASE_MASK | gtk.gdk.BUTTON_PRESS_MASK|gtk.gdk.POINTER_MOTION_MASK)
         self.g_d.connect("button_press_event", self.on_button_press_event)
 
         self.g_pixmap = None
@@ -90,7 +91,7 @@ class MusicDisplayer(gtk.ScrolledWindow):
         self.white_gc = self.g_d.get_style().white_gc
         self.black_gc = self.g_d.get_style().black_gc
         dim = engravers.dimentions[self.m_fontsize]
-        #if self.g_pixmap == None:
+        #if self.g_pixmap is None:
         if 1==1:
             d = self.get_allocation()
             if self.m_width < d[2]:
@@ -119,3 +120,42 @@ class MusicDisplayer(gtk.ScrolledWindow):
                 staff_centrum = staff_centrum + dim.staff_spacing
         return##############
         darea.draw_pixmap(self.white_gc, self.g_pixmap, 0, 0, 0, 0, self.m_width, self.m_height)
+
+class ChordEditor(MusicDisplayer):
+    def __init__(self):
+        MusicDisplayer.__init__(self, None)
+        self._yp = None
+        self.g_d.connect("button_release_event", self.on_button_release_event)
+        self.g_d.connect("event", self.on_event)
+        self.m_cursor = None
+    def set_cursor(self, cursor):
+        self.m_cursor = cursor
+    def on_button_release_event(self, arg1, event):
+        dim = engravers.dimentions[self.m_fontsize]
+        dist = int((event.y - dim.first_staff_ypos) / dim.linespacing * 2)
+        self.emit('clicked', dist)
+    def on_event(self, drawingarea, event):
+        if event.type == gtk.gdk.MOTION_NOTIFY:
+            dim = engravers.dimentions[self.m_fontsize]
+            dist = int((event.y - dim.first_staff_ypos) / dim.linespacing * 2)
+            self._yp = dist
+            self.queue_draw()
+    def on_expose_event(self, darea, event):
+        MusicDisplayer.on_expose_event(self, darea, event)
+        dim = engravers.dimentions[self.m_fontsize]
+        if self.m_cursor is not None:
+            staff_centrum = dim.first_staff_ypos
+            from soundcard.rat import Rat
+            if self.m_cursor == 'erase':
+                return
+            if self.m_cursor == 'notehead':
+                eng = engravers.NoteheadEngraver(Rat(0,1), "20-tight", 0, self._yp, 2, 0, 0, 0)
+            else:
+                eng = engravers.AccidentalsEngraver(Rat(0,1), "20-tight", {self._yp: [int(self.m_cursor)]})
+            eng.m_xpos = 50
+            eng.engrave(darea, self.black_gc, staff_centrum)
+
+gobject.signal_new('clicked', ChordEditor, gobject.SIGNAL_RUN_FIRST,
+    gobject.TYPE_NONE, (gobject.TYPE_PYOBJECT,))
+
+
