@@ -35,7 +35,7 @@ To get bar lines you have to insert a '|'
 
 import weakref
 
-import string, re
+import re
 from duration import Duration
 from musicalpitch import MusicalPitch
 from engravers import *
@@ -130,7 +130,7 @@ class Score:
         self.m_timeposdict = {}
         self.m_staffs = []
     def announce_timepos(self, timepos):
-        if not self.m_timeposdict.has_key(timepos):
+        if timepos not in self.m_timeposdict:
             self.m_timeposdict[timepos] = ScoreColObj()
     def get_engravers(self, fontsize):
         tv = self.m_timeposdict.keys()
@@ -155,9 +155,9 @@ class Score:
             tuplet = None
             for voice in staff.m_voice_list:
                 for timepos in tv:
-                    if not staff.m_coldict.has_key(timepos):
+                    if timepos not in staff.m_coldict:
                         continue
-                    if not voice.m_coldict.has_key(timepos):
+                    if timepos not in voice.m_coldict:
                         continue
                     if staff.m_coldict[timepos].m_clef:
                         clef = staff.m_coldict[timepos].m_clef
@@ -197,7 +197,7 @@ class Score:
             ###################
             # this loop takes care of stuff that is decided on a per-staff-basis
             for timepos in tv:
-                if not staff.m_coldict.has_key(timepos):
+                if timepos not in staff.m_coldict:
                     continue
                 # clef
                 if staff.m_coldict[timepos].m_clef:
@@ -233,13 +233,12 @@ class Score:
                 # accidentals
                 v = {}
                 for voice in staff.m_voice_list:
-                    if not voice.m_coldict.has_key(timepos):
+                    if timepos not in voice.m_coldict:
                         continue
-                    for musicalpitch in voice.m_coldict[timepos].m_music.keys():
-                        m = voice.m_coldict[timepos].m_music[musicalpitch].m_pitch
-                        e = staff.needed_accidental(m)
+                    for music in voice.m_coldict[timepos].m_music.itervalues():
+                        e = staff.needed_accidental(music.m_pitch)
                         if e is not None:
-                            v[mpdutils.steps_to_ylinepos(m.steps(), clef)] = e
+                            v[mpdutils.steps_to_ylinepos(music.m_pitch.steps(), clef)] = e
                 if v:
                     se.append(AccidentalsEngraver(timepos, fontsize, v))
                     self.m_timeposdict[timepos].m_accidentals \
@@ -256,9 +255,9 @@ class Score:
                     voicelist = [staff.m_voice_list[0]]
                 else:
                     def f(A, B, timepos=timepos):
-                        if not B.m_coldict.has_key(timepos):
+                        if timepos not in B.m_coldict:
                             return 1
-                        if not A.m_coldict.has_key(timepos):
+                        if timepos not in A.m_coldict:
                             return 1
                         return cmp(B.m_coldict[timepos].m_music.values()[0].m_pitch.semitone_pitch(), A.m_coldict[timepos].m_music.values()[0].m_pitch.semitone_pitch())
                         return 1
@@ -266,18 +265,18 @@ class Score:
                     voicelist = staff.m_voice_list
                 voice1_lowest_ylinepos = None
                 for voice in voicelist:
-                    if not voice.m_coldict.has_key(timepos):
+                    if timepos not in voice.m_coldict:
                         continue
                     # nd:
                     # * the keys in the dictionary is the position on the
                     #   staff the notehead will have. 0 is the middle line,
                     #   1 is below the middle line, -2 is on the line above
                     #   the middle line.
-                    # * the values is the requests.Music that represents
+                    # * the values is the requests.MusicRequest that represents
                     #   the notehead.
                     nd = {}
-                    for musicalpitch in voice.m_coldict[timepos].m_music.keys():
-                        nd[mpdutils.steps_to_ylinepos(voice.m_coldict[timepos].m_music[musicalpitch].m_pitch.steps(), clef)] = voice.m_coldict[timepos].m_music[musicalpitch]
+                    for mm in voice.m_coldict[timepos].m_music.itervalues():
+                        nd[mpdutils.steps_to_ylinepos(mm.m_pitch.steps(), clef)] = mm
                     if nd == {}:
                         # nd == {} when there are not noteheads, for example
                         # when there is a rest here.
@@ -311,20 +310,19 @@ class Score:
                 #####################################
                 # create notehead and rest engravers
                 for voice in staff.m_voice_list:
-                    if not voice.m_coldict.has_key(timepos):
+                    if timepos not in voice.m_coldict:
                         continue
-                    for k in voice.m_coldict[timepos].m_music.keys():
-                        m = voice.m_coldict[timepos].m_music[k]
-                        if m.m_duration.m_nh < 2:
+                    for music in voice.m_coldict[timepos].m_music.itervalues():
+                        if music.m_duration.m_nh < 2:
                             head = const.NOTEHEAD_0
-                        elif m.m_duration.m_nh > 2:
+                        elif music.m_duration.m_nh > 2:
                             head = const.NOTEHEAD_2
                         else:
                             head = const.NOTEHEAD_1
-                        ylinepos = mpdutils.steps_to_ylinepos(m.m_pitch.steps(), clef)
-                        se.append(NoteheadEngraver(timepos, fontsize, m.m_shift,
-                             ylinepos, head, m.m_duration.m_dots,
-                             m.m_pitch.semitone_pitch(),
+                        ylinepos = mpdutils.steps_to_ylinepos(music.m_pitch.steps(), clef)
+                        se.append(NoteheadEngraver(timepos, fontsize, music.m_shift,
+                             ylinepos, head, music.m_duration.m_dots,
+                             music.m_pitch.semitone_pitch(),
                              voice.m_coldict[timepos]))
                         self.m_timeposdict[timepos].m_music \
                            = max(self.m_timeposdict[timepos].m_music, se[-1].get_width())
@@ -343,10 +341,10 @@ class Score:
                 up = 0
                 down = 0
                 for voice in staff.m_voice_list:
-                    if not voice.m_coldict.has_key(timepos):
+                    if timepos not in voice.m_coldict:
                         continue
-                    for k in voice.m_coldict[timepos].m_music.keys():
-                        ypos = voice.m_coldict[timepos].m_music[k].m_pitch.steps()
+                    for music in voice.m_coldict[timepos].m_music.itervalues():
+                        ypos = music.m_pitch.steps()
                         ypos = mpdutils.steps_to_ylinepos(ypos, clef)
                         if up > ypos < -5:
                             up = ypos
@@ -354,7 +352,7 @@ class Score:
                             down = ypos
                 ###############################
                 # Create ledger line engravers
-                if staff.m_coldict.has_key(timepos):
+                if timepos in staff.m_coldict:
                     if up:
                         up = - up / 2 - 2
                     else:
@@ -504,7 +502,7 @@ class Staff:
             self.m_accidentals_info[steps] = m.m_accidental_i
             return [m.m_accidental_i]
     def barline(self, timepos):
-        #assert not self.m_coldict.has_key(timepos)
+        #assert timepos not in self.m_coldict
         self.m_coldict[timepos] = StaffColObj()
         self.m_coldict[timepos].m_barline = 1
     def add_timesignature(self, t, timepos):
@@ -516,11 +514,11 @@ class Staff:
     def add_clef(self, timepos, clef):
         self.m_coldict[timepos].m_clef = clef
     def announce_timepos(self, timepos):
-        if not self.m_coldict.has_key(timepos):
+        if timepos not in self.m_coldict:
             self.m_coldict[timepos] = StaffColObj()
             self.w_score().announce_timepos(timepos)
     def maybe_ledger_lines(self, timepos, ypos):
-        if not self.m_coldict.has_key(timepos):
+        if timepos not in self.m_coldict:
             self.m_coldict[timepos] = StaffColObj()
         if self.m_coldict[timepos].m_ledger_up > ypos < -5:
             self.m_coldict[timepos].m_ledger_up = ypos
@@ -538,10 +536,10 @@ class Voice:
         self.m_is_beaming = None
         self.m_doing_tuplet = None
     def add_notehead(self, timepos, music, stemdir):
-        assert self.m_coldict.has_key(timepos)
+        assert timepos in self.m_coldict
         key = (music.m_pitch.steps(), music.m_pitch.m_accidental_i)
         if __debug__:
-            if self.m_coldict[timepos].m_music.has_key(key):
+            if key in self.m_coldict[timepos].m_music:
                 print "warning, adding the same notehead twice", key
             if (self.m_coldict[timepos].m_duration is not None) \
                and (self.m_coldict[timepos].m_duration != music.m_duration):
@@ -555,14 +553,14 @@ class Voice:
         self.m_coldict[timepos].m_music[key] = music
         self.m_coldict[timepos].m_stemdir = stemdir
     def add_rest(self, rest, timepos):
-        assert self.m_coldict.has_key(timepos)
+        assert timepos in self.m_coldict
         self.m_coldict[timepos].m_rest = rest
     def announce_timepos2(self, timepos):
-        if not self.m_coldict.has_key(timepos):
+        if timepos not in self.m_coldict:
             self.m_coldict[timepos] = VoiceColObj()
             self.w_parent_staff().announce_timepos(timepos)
     def announce_timepos(self, timepos):
-        if not self.m_coldict.has_key(timepos):
+        if timepos not in self.m_coldict:
             self.m_coldict[timepos] = VoiceColObj()
             if self.m_is_beaming:
                 self.m_coldict[timepos].m_beaminfo = 'continue'
@@ -585,8 +583,8 @@ class Voice:
             print "mpd-warning: we are not beaming, ignoring stop_beam request"
         self.m_is_beaming = 0
     def do_tie_end(self, pos1, pos2):
-        for p in self.m_coldict[pos1].m_music.keys():
-            if self.m_coldict[pos2].m_music.has_key(p):
+        for p in self.m_coldict[pos1].m_music:
+            if p in self.m_coldict[pos2].m_music:
                 self.m_ties.append((pos1, pos2, p,
                        # need these to generate midi track
                        self.m_coldict[pos1].m_music[p],
@@ -607,27 +605,27 @@ class Voice:
         for idx in range(len(kv)):
             coltimepos = kv[idx]
             musictimepos = musictimepos + (coltimepos - last_timepos)
-            if self.m_coldict.has_key(coltimepos):
+            if coltimepos in self.m_coldict:
                 for n in self.m_coldict[coltimepos].m_music.values():
                     #FIXME this is ugly
                     if id(n) in tie_from_v and (id(n) not in tie_to_v):
                         id_D[n.m_pitch.semitone_pitch()] = i
-                        if not D.has_key(musictimepos):
+                        if musictimepos not in D:
                             D[musictimepos] = []
                         D[musictimepos].append((i, const.START_NOTE, n.m_pitch.semitone_pitch()))
                     elif id(n) in tie_to_v:
                         stop_pos = musictimepos + n.m_duration.get_rat_value()
-                        if not D.has_key(stop_pos):
+                        if stop_pos not in D:
                             D[stop_pos] = []
                         D[stop_pos].append((id_D[n.m_pitch.semitone_pitch()],
                                const.STOP_NOTE, n.m_pitch.semitone_pitch()))
                     else:
-                        if not D.has_key(musictimepos):
+                        if musictimepos not in D:
                             D[musictimepos] = []
                         D[musictimepos].append((i, const.START_NOTE, n.m_pitch.semitone_pitch()))
 
                         stop_pos = musictimepos + n.m_duration.get_rat_value()
-                        if not D.has_key(stop_pos):
+                        if stop_pos not in D:
                             D[stop_pos] = []
                         D[stop_pos].append((i, const.STOP_NOTE, n.m_pitch.semitone_pitch()))
                         i = i + 1
@@ -848,7 +846,7 @@ class Lexer:
     re_key = re.compile(r"\s*\\key\s+([a-z]+)\s*\\(major|minor)", re.UNICODE)
     re_times = re.compile(r"\s*\\times\s+(\d+)\s*/\s*(\d+)\s*{", re.UNICODE)
     def __init__(self, s):
-        self.m_string = string.strip(s)
+        self.m_string = s.strip()
         self.m_notelen = Duration(4, 0)
         self.m_idx = 0
     def get(self):
@@ -899,7 +897,7 @@ class Lexer:
                 if dots:
                     #FIXME
                     raise ParseError("LexerError")
-            n = Music(notename, notelen, numdots)
+            n = MusicRequest(notename, notelen, numdots)
             if not n.m_duration:
                 n.m_duration = self.m_notelen.clone()
             else:
