@@ -22,24 +22,13 @@
 
 import sys
 
-if sys.version_info < (2, 3):
-    print "********************************************************************"
-    print "Solfege need Python 2.3 or newer. The configure script told you so!"
-    print "********************************************************************"
-    sys.exit(-1)
-
 import src
 import src.configureoutput
 
 src.configureoutput.prefix = "."
 
 import src.cfg
-__builtins__.app_running = True
-__builtins__.__exdata__ = []
 src.cfg.initialise(None, "default.config", "~/.solfegerc")
 
-if '--txtui' in sys.argv:
-    import src.txtui
-else:
-    import src.mainwin
+import src.mainwin
 
