@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import sys, os, tempfile, string, signal
+import sys, os, tempfile, signal
 import mfutils
 
 def ms_win_kill(pid):
@@ -46,9 +46,10 @@ class MidiFileSynth:
             # create the file so nobody else takes it
             fd = os.open(fn, os.O_CREAT|os.O_EXCL|os.O_TRUNC|os.O_RDWR, 0600)
             os.close(fd)
-        except:
+        except IOError, e:
             print "trouble creating tmp file. This should *not* happen."
             print "Please complaint to bug-solfege@gnu.org"
+            print "Exception:", e
             raise "Shit"
     def close(self):
         pass
@@ -61,6 +62,10 @@ class MidiFileSynth:
     def _play_track_fork_execl(self, track):
         track.prepend_bpm(60)
         self.create_midifile(track)
+        if not os.path.isfile(self.m_cmd.split()[0]):
+            print >> sys.stderr, "The program '%s' does not exist." % self.m_cmd.split()[0]
+            print >> sys.stderr, "Please check the sound setup in the preferences window."
+            return
         if self.__child_pid:
             try:
                 os.kill(self.__child_pid, signal.SIGKILL)
@@ -70,10 +75,10 @@ class MidiFileSynth:
             self.__child_pid = None
         pid = os.fork()
         if pid == 0:
-            v = string.split(self.m_cmd % self.m_tmpfilename, " ")
+            v = (self.m_cmd % self.m_tmpfilename).split(" ")
             v = v[:1] + [""] + v[1:]
             try:
-                apply(os.execlp, v)
+                os.execlp(*v)
             except OSError, x:
                 print "OSError while trying to invoke external midiplayer:", x
                 print "Please check your sound setup!"
