@@ -70,7 +70,7 @@ class OSSSequencerSynth(oss_common.AbstractSynth):
             return None
         # first, if NOTE is already playing on channel CHAN, we need
         # to stop it and free the voice used for that.
-        if self.m_channel_dict[chan].has_key(note):
+        if note in self.m_channel_dict[chan]:
             solfege_c_midi.seq_stop_note(self.m_devnum,
                                     self.m_channel_dict[chan][note], note, 100)
             self.free_voice(chan, note)
@@ -80,11 +80,11 @@ class OSSSequencerSynth(oss_common.AbstractSynth):
             # we need to set the patch for this voice
             solfege_c_midi.seq_set_patch(self.m_devnum, voice, p)
             self.m_voice_patches[voice] = p
-        assert not self.m_channel_dict[chan].has_key(note)
+        assert note not in self.m_channel_dict[chan]
         self.m_channel_dict[chan][note] = voice
         return voice
     def free_voice(self, chan, note):
-        if not self.m_channel_dict[chan].has_key(note):
+        if note not in self.m_channel_dict[chan]:
             return None
         voice = self.m_channel_dict[chan][note]
         self.m_voices.append(voice)
