@@ -16,7 +16,6 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import rat
-import types
 
 class Track:
     TEMPO = 'tempo'
@@ -40,7 +39,7 @@ class Track:
         assert 0 <= chn < 16
         self.m_v.append([self.NOTE_OFF, chn, int(pitch), vel])
     def notelen_time(self, notelen):
-        if type(notelen) == types.IntType:
+        if isinstance(notelen, int):
             self.m_v.append([self.NOTELEN_TIME, rat.Rat(1, notelen)])
         else:
             assert isinstance(notelen, rat.Rat)
@@ -71,7 +70,7 @@ class Track:
                 if event[0] == Track.NOTELEN_TIME:
                     pos = pos + event[1]
                 else:
-                    if not D.has_key(pos):
+                    if pos not in D:
                         D[pos] = []
                     D[pos].append(event)
         kv = D.keys()
@@ -84,7 +83,9 @@ class Track:
         for event in D[kv[-1]]:
             self.m_v.append(event)
     def replace_note(self, old, new, chan):
-        assert type(old) == type(new) == type(chan) == types.IntType
+        assert isinstance(old, int)
+        assert isinstance(new, int)
+        assert isinstance(chan, int)
         for event in self.m_v:
             if event[0] in (Track.NOTE_ON, Track.NOTE_OFF) \
                    and event[1] == chan and event[2] == old:
