@@ -22,11 +22,10 @@ import widgets
 import soundcard, mpd
 import dataparser
 
-import const, utils, string
+import const, utils
 import os
 import sys
 import signal
-import types
 import cfg
 
 class Teacher(cfg.ConfigUtils):
@@ -36,8 +35,8 @@ class Teacher(cfg.ConfigUtils):
         self.q_status = const.QSTATUS_NO
         self.m_statistics = None
         self.m_timeout_handle = None
-        for k in config.keys():
-            self.set_string(k, dict[k])
+        for key, val in config.iteritems():
+            self.set_string(key, val)
     def get_instrument_config(self, num):
         if self.get_bool('override_default_instrument'):
             instr_low = self.get_int('lowest_instrument')
@@ -70,7 +69,7 @@ class Teacher(cfg.ConfigUtils):
         self.q_status = const.QSTATUS_NO
         soundcard.synth.stop()
     def configure_exercise(self, collection, lessonfile, D):
-        for k in D.keys():
+        for k in D:
             self.set_string(k, D[k])
 
 class MelodicIntervalTeacher(Teacher):
@@ -88,8 +87,8 @@ class MelodicIntervalTeacher(Teacher):
         self.m_tonika = None
         self.m_question = []
     def new_question(self, L, H):
-        assert type(L) in types.StringTypes
-        assert type(H) in types.StringTypes
+        assert isinstance(L, basestring)
+        assert isinstance(H, basestring)
         if self.get_list('ask_for_intervals_0') == []:
             return self.ERR_CONFIGURE
         L, H = utils.adjust_low_high_to_irange(L, H,
@@ -226,7 +225,7 @@ You really should reastart the program now.""")
             run = self.m_app.m_ui.dialog_yesno(_("The lessonfile contain potentially dangerous code because the lesson file set the variable \"musicformat\" to \"cmdline\". Run anyway?"))
             if not run:
                 self.m_P = None
-    def configure_exercise(self, lessoncollection, lessonfile, dict):
+    def configure_exercise(self, lessoncollection, lessonfile, config):
     	"""This function should not be called by the constructors.
 	abstract.Teacher and abstract.LessonbasedTeacher does the same job,
 	but in correct order.
@@ -236,8 +235,8 @@ You really should reastart the program now.""")
                 self.set_string('lessoncollection', lessoncollection)
             if lessonfile:
                 self.set_string('lessonfile', lessonfile)
-        for k in dict.keys():
-            self.set_string(k, dict[k])
+        for key, val in config.iteritems():
+            self.set_string(key, val)
 
 class Gui(gtk.VBox, cfg.ConfigUtils):
     """Important members:
@@ -291,7 +290,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
     def on_key_press_event(self, widget, event):
         if (self.g_notebook is None or self.g_notebook.get_current_page() == 0) \
            and event.type == gtk.gdk.KEY_PRESS:
-            for s in self.m_key_bindings.keys():
+            for s in self.m_key_bindings:
                 if self.keymatch(event, s):
                     self.m_key_bindings[s]()
                     return 1
