@@ -45,7 +45,7 @@ class RunExternalFailed(Exception):
 __child_pid = None
 def run_external_program(cmdstring, wdir, argument):
     global __child_pid
-    if cmdstring.find("%s") == -1:
+    if "%s" not in cmdstring:
         cmdline = "%s %s" % (cmdstring, argument)
     else:
         cmdline = cmdstring % argument
@@ -74,7 +74,7 @@ def run_external_program(cmdstring, wdir, argument):
     if pid == 0:
         os.chdir(wdir)
         try:
-            apply(os.execlp, v)
+            os.execlp(*v)
         except OSError, x:
             print >> sys.stderr, "OS Error:", x
             os._exit(-1)
@@ -147,6 +147,7 @@ the preferences window.
                              verbose_init='--verbose-sound-init' in self.m_argv)
             except (soundcard.SoundInitException, OSError), e:
                 self.m_sound_init_exception = e
+                soundcard.initialise_using_fake_synth(True)
     def display_sound_init_error_message(self, e):
         if isinstance(e, soundcard.SoundInitException):
             self.m_ui.display_error_message(
@@ -190,7 +191,7 @@ It is also possible that the OS sound setup is incorrect.
                 self.m_ui.m_history.set_adj_of_current(self.m_ui.box_dict['docviewer'].get_vadjustment().value)
         protocol, action, fn, anchor, lessoncollection, lessonfile, config = \
            utils.parse_url(href)
-        if protocol == None:
+        if protocol is None:
             if fn.endswith(".midi"):
                 run_external_program(self.get_string("sound/midi_player"),
                         self.m_ui.box_dict['docviewer'].m_htmlwidget.m_document_wd, fn)
@@ -207,13 +208,14 @@ It is also possible that the OS sound setup is incorrect.
                         self.m_ui.display_error_message("Lessonfile not found:\n%s" % filepath)
                         return
                 if (self.m_ui.m_viewer == 'docviewer'
-                    and self.m_running_exercise != None
+                    and self.m_running_exercise is not None
                     and self.m_running_exercise != fn) or \
                    (self.m_ui.m_viewer != 'docviewer'):
                        self.m_ui.box_dict[self.m_running_exercise].on_end_practise()
                        self.m_running_exercise = None
                 _old_viewer = self.m_ui.m_viewer
-                if not self.m_teachers.has_key(fn):
+                if fn not in self.m_teachers:
+                    new_ex = True
                     n = utils.exercise_name_to_module_name(fn)
                     exec("import %s" % n)
                     if issubclass(locals()[n].Teacher, abstract.LessonbasedTeacher):
@@ -225,10 +227,13 @@ It is also possible that the OS sound setup is incorrect.
                     self.m_ui.initialise_exercise(self.m_teachers[fn])
                     self.m_teachers[fn].g_view = self.m_ui.box_dict[fn]
                 else:
+                    new_ex = False
                     self.m_teachers[fn].configure_exercise(lessoncollection, lessonfile, config)
                 self.m_ui.activate_exercise(href)
+                if not new_ex:
+                    self.m_ui.box_dict[fn].update_gui_after_lessonfile_change()
                 if not (_old_viewer == 'docviewer'
-                        and self.m_running_exercise != None
+                        and self.m_running_exercise is not None
                         and self.m_running_exercise == fn):
                     self.m_ui.box_dict[self.m_ui.m_viewer].on_start_practise()
                 self.m_running_exercise = fn
@@ -240,9 +245,9 @@ It is also possible that the OS sound setup is incorrect.
             print "unknown link type", protocol
     def quit_program(self):
         cfg.sync()
-        for k in self.m_teachers.keys():
-            if self.m_teachers[k].m_statistics is not None:
-                self.m_teachers[k].m_statistics.save_data()
+        for teacher in self.m_teachers.itervalues():
+            if teacher.m_statistics is not None:
+                teacher.m_statistics.save_data()
         if soundcard.synth:
             soundcard.synth.close()
 
