@@ -75,8 +75,7 @@ True
 True
 """
 
-import string, re
-import types
+import re
 import os, os.path, sys
 
 # It is a know fact that many windows lusers are $HOMEless
@@ -92,13 +91,13 @@ comment_re = re.compile("#.*")
 # if this still works, and if so, delete the commented lines.
 def split(key):
    #if "/" in key:
-       return string.split(key, "/")
+       return key.split("/")
    #else:
-   #    return string.split(key, "\\")
+   #    return key.split("\\")
 
-def parse_file_into_dict(dict, filename):
-    file = open(filename, "r")
-    line = file.readline()
+def parse_file_into_dict(dictionary, filename):
+    f = file(filename, "r")
+    line = f.readline()
     section = None
     while line:
         section_m = section_re.match(line)
@@ -108,19 +107,19 @@ def parse_file_into_dict(dict, filename):
             pass
         elif section_m:
             section = section_m.groups()[0]
-            if not dict.has_key(section):
-                dict[section] = {}
+            if section not in dictionary:
+                dictionary[section] = {}
         elif value_m:
             assert section
-            dict[section][value_m.groups()[0]] = value_m.groups()[1]
+            dictionary[section][value_m.groups()[0]] = value_m.groups()[1]
         elif line == "\n":
             pass
         else:
            print filename
            raise Exception("Shit happended line %s" % line)
-        line = file.readline()
-    file.close()
-    return dict
+        line = f.readline()
+    f.close()
+    return dictionary
 
 
 def sync():
@@ -129,7 +128,7 @@ def sync():
 def _maybe_create_key(key):
     global data
     section, k = split(key)
-    if not data.has_key(section):
+    if section not in data:
         data[section] = {}
 
 ########################
@@ -142,34 +141,34 @@ def set_string(key, val):
     section, k = split(key)
     oldval = get_string(key)
     data[section][k] = val
-    if _watches.has_key(key) and (oldval != get_string(key)):
-        if _blocked_watches.has_key(key) and _blocked_watches[key] > 0:
+    if key in _watches and (oldval != get_string(key)):
+        if key in _blocked_watches and _blocked_watches[key] > 0:
             return
         for cb in _watches[key].values():
             cb(key)
 
 def set_int(key, val):
     global data, _watches, _blocked_watches
-    assert type(val) == types.IntType
+    assert isinstance(val, int)
     _maybe_create_key(key)
     section, k = split(key)
     oldval = get_string(key)
     data[section][k] = str(val)
-    if _watches.has_key(key) and (oldval != get_string(key)):
-        if _blocked_watches.has_key(key) and _blocked_watches[key] > 0:
+    if key in _watches and (oldval != get_string(key)):
+        if key in _blocked_watches and _blocked_watches[key] > 0:
             return
         for cb in _watches[key].values():
             cb(key)
 
 def set_float(key, val):
     global data, _watches, _blocked_watches
-    assert type(val) == types.FloatType
+    assert isinstance(val, float)
     _maybe_create_key(key)
     section, k = split(key)
     oldval = get_string(key)
     data[section][k] = str(val)
-    if _watches.has_key(key) and (oldval != get_string(key)):
-        if _blocked_watches.has_key(key) and _blocked_watches[key] > 0:
+    if key in _watches and (oldval != get_string(key)):
+        if key in  _blocked_watches and _blocked_watches[key] > 0:
             return
         for cb in _watches[key].values():
             cb(key)
@@ -189,8 +188,8 @@ def set_list(key, val):
 ########################
 
 def get_string(key):
-    if len(string.split(key, "=")) == 2:
-        key, default = string.split(key, "=")
+    if len(key.split("=")) == 2:
+        key, default = key.split("=")
     else:
         default = ""
     section, k = split(key)
@@ -200,8 +199,8 @@ def get_string(key):
         return default
 
 def get_int(key):
-   if len(string.split(key, "=")) == 2:
-      key, default = string.split(key, "=")
+   if len(key.split("=")) == 2:
+      key, default = key.split("=")
    else:
       default = 0
    section, k = split(key)
@@ -214,8 +213,8 @@ def get_int(key):
        return int(default)
 
 def get_float(key):
-   if len(string.split(key, "=")) == 2:
-      key, default = string.split(key, "=")
+   if len(key.split("=")) == 2:
+      key, default = key.split("=")
    else:
       default = 0
    section, k = split(key)
@@ -225,8 +224,8 @@ def get_float(key):
        return float(default)
 
 def get_list(key):
-    if len(string.split(key, "=")) == 2:
-        key, default = string.split(key, "=")
+    if len(key.split("=")) == 2:
+        key, default = key.split("=")
     else:
         default = []
     section, k = split(key)
@@ -249,10 +248,10 @@ def del_key(key):
     global data, _watches, _blocked_watches
     section, k = split(key)
     #FIXME watches
-    if not data.has_key(section):
+    if section not in data:
         print >> sys.stderr, "cfg.del_key: section does not exist"
         return
-    if not data[section].has_key(k):
+    if k not in data[section]:
         print >> sys.stderr, "cfg.del_key: section '%s' does not have key '%s'" % (section, k)
         return
     del data[section][k]
@@ -265,9 +264,9 @@ def del_key(key):
 
 def dump(dict, fn):
     f = open(fn, 'w')
-    for section in dict.keys():
+    for section in dict:
         f.write("[%s]\n" % section)
-        for name in dict[section].keys():
+        for name in dict[section]:
             f.write("%s=%s\n" % (name, dict[section][name]))
         f.write("\n")
     f.close()
@@ -333,19 +332,19 @@ class ConfigUtils(object):
         """
         global _blocked_watches
         name = self._expand_name(name)
-        if not _blocked_watches.has_key(name):
+        if name not in _blocked_watches:
             _blocked_watches[name] = 0
         _blocked_watches[name] += 1
     def unblock_watch(self, name):
         global _blocked_watches
         name = self._expand_name(name)
-        assert _blocked_watches.has_key(name)
+        assert name in _blocked_watches
         assert _blocked_watches[name] > 0
         _blocked_watches[name] -= 1
     def add_watch(self, name, callback):
         global _watches, _watch_counter
         name = self._expand_name(name)
-        if not _watches.has_key(name):
+        if name not in _watches:
             _watches[name] = {}
         _watches[name][_watch_counter] = callback
         _watch_counter += 1
@@ -353,8 +352,8 @@ class ConfigUtils(object):
     def remove_watch(self, name, id):
         global _watches, _watch_counter
         name = self._expand_name(name)
-        if _watches.has_key(name):
-            if _watches[name].has_key(id):
+        if name in _watches:
+            if id in _watches[name]:
                 del _watches[name][id]
                 if _watches[name] == {}:
                     del _watches[name]
@@ -363,7 +362,7 @@ class ConfigUtils(object):
         else:
             print "warning: remove_watch: name is not watched:", name
     def _expand_name(self, name):
-        if string.count(name, "/") == 0:
+        if name.count("/") == 0:
             return "%s/%s" % (self.m_exname, name)
         return name
     ######
