@@ -30,7 +30,6 @@ import gtk, gnome
 import gu, widgets
 import soundcard, mpd, mpd.musicdisplayer
 import abstract, const, lessonfile
-import string
 import utils
 import soundcard
 import dataparser
@@ -50,10 +49,10 @@ class Teacher(abstract.LessonbasedTeacher):
         abstract.LessonbasedTeacher.__init__(self, exname, app,
               lesson_collection, lesson_file, config)
         self.lessonfileclass = lessonfile.ChordLessonfile
-        try: # the lessonfile might contain errors.
+        try: # try: because the file can have changed since startup
             self.parse_lessonfile()
         except dataparser.DataparserException, e:
-            self.m_app.m_ui.display_error_message(str(e))
+            self.m_app.m_ui.display_exception_message(e, __file__)
     def new_question(self):
         """
         return OK or ERR_PICKY
@@ -114,7 +113,7 @@ class Teacher(abstract.LessonbasedTeacher):
         """
         GUI guarantees that this method will not be called after it has
         been guessed correct once.
-        
+
         return 0 if this was wrong guess.
         return CORRECT if this question is correct.
         return ALL_CORRECT if all parts of the question is correct.
@@ -211,9 +210,9 @@ class Gui(abstract.LessonbasedGui):
               + self.g_toptone_box.get_children():
             x.destroy()
         if self.m_t.m_P:
-            for t in self.m_t.m_P.m_chord_types.keys():
-                b = gtk.Button(self.m_t.m_P.m_chord_types[t])
-                b.set_data('type', t)
+            for ctype, translated_type in self.m_t.m_P.m_chord_types.iteritems():
+                b = gtk.Button(translated_type)
+                b.set_data('type', ctype)
                 b.connect('clicked', self.on_type)
                 b.connect('button_release_event', self.on_type)
                 self.g_chordtype_box.pack_start(b, False)
@@ -259,7 +258,8 @@ class Gui(abstract.LessonbasedGui):
         if event is None:
             self.on_type_left_clicked(button)
         elif event.button == 3:
-            self.on_type_right_clicked(button)
+            if self.m_t.m_P and self.m_t.m_P.header.enable_right_click:
+                self.on_type_right_clicked(button)
     def on_type_left_clicked(self, button):
         if self.m_t.q_status in (const.QSTATUS_NO, const.QSTATUS_GIVE_UP)\
           or self.m_t.m_correct[0]:
@@ -280,13 +280,13 @@ class Gui(abstract.LessonbasedGui):
             self.g_new.grab_focus()
             self.g_give_up.set_sensitive(False)
     def on_type_right_clicked(self, button):
-        #if not self.m_t.ok_to_right_click_type(): #FIXME
-        #    return 
+        if self.m_t.q_status == const.QSTATUS_NO:
+            return
         if not self.m_t.m_P.has_question():
             return
         if self.m_t.m_P.get_toptone() == -1 \
                 and self.m_t.m_P.get_inversion() == -1:
-            if self.m_t.m_P.get_question().has_key('set'):
+            if 'set' in self.m_t.m_P.get_question():
                 for question in self.m_t.m_P.m_questions:
                     if question['set'] == self.m_t.m_P.get_question()['set'] \
                         and question.get_cname() == button.get_data('type'):
@@ -323,7 +323,8 @@ class Gui(abstract.LessonbasedGui):
         if event is None:
             self.on_inversion_left_clicked(button)
         elif event.button == 3:
-            self.on_inversion_right_clicked(button)
+            if self.m_t.m_P and self.m_t.m_P.header.enable_right_click:
+                self.on_inversion_right_clicked(button)
     def on_inversion_left_clicked(self, button):
         if self.m_t.q_status in (const.QSTATUS_NO, const.QSTATUS_GIVE_UP) \
           or self.m_t.m_correct[1]:
@@ -371,7 +372,8 @@ class Gui(abstract.LessonbasedGui):
         if not event:
             self.on_toptone_left_clicked(button)
         elif event.button == 3:
-            self.on_toptone_right_clicked(button)
+            if self.m_t.m_P and self.m_t.m_P.header.enable_right_click:
+                self.on_toptone_right_clicked(button)
     def on_toptone_right_clicked(self, button):
         if not self.m_t.m_P.has_question():
             return
@@ -410,6 +412,12 @@ class Gui(abstract.LessonbasedGui):
         self.g_new.set_sensitive(True)
         self.g_give_up.set_sensitive(False)
     def new_question(self, widget=None):
+        def exception_cleanup():
+            soundcard.synth.stop()
+            self.g_give_up.set_sensitive(False)
+            self.g_repeat.set_sensitive(False)
+            self.g_repeat_arpeggio.set_sensitive(False)
+            self.m_t.q_status = const.QSTATUS_NO
         # if we have no lessonfile, then we have to questions.
         if not self.m_t.m_P:
             return
@@ -417,20 +425,10 @@ class Gui(abstract.LessonbasedGui):
         for button in self.g_chordtype_box.get_children() \
                     + self.g_inversion_box.get_children() \
                     + self.g_toptone_box.get_children():
-            #button.set_sensitive(True)
             button.get_children()[0].set_name("")
         ##
         try:
             n = self.m_t.new_question()
-        except mpd.MpdException, e:
-            soundcard.synth.stop()
-            self.g_win.display_question_music_error_message(
-               self.m_t.m_P._idx, self.get_string('lessonfile'), e)
-            self.g_give_up.set_sensitive(False)
-            self.g_repeat.set_sensitive(False)
-            self.g_repeat_arpeggio.set_sensitive(False)
-            self.m_t.q_status = const.QSTATUS_NO
-        else:
             if n == Teacher.ERR_PICKY:
                 print "picky!"
             else:
@@ -447,6 +445,16 @@ class Gui(abstract.LessonbasedGui):
                 self.g_inversion_box.set_sensitive(self.m_t.m_P.get_inversion() != -1)
                 self.g_toptone_box.set_sensitive(self.m_t.m_P.get_toptone() != -1)
                 self.g_chordtype_box.get_children()[0].grab_focus()
+        except lessonfile.LessonfileException, e:
+            # This exception will be raised if for example the music
+            # type for a question is invalid.
+            exception_cleanup()
+            self.g_win.display_exception_message(e, __file__)
+        except mpd.MpdException, e:
+            # Invalid key variable or music code goes here.
+            exception_cleanup()
+            self.g_win.display_question_music_error_message(
+                self.m_t.m_P._idx, self.get_string('lessonfile'), e)
     def on_start_practise(self):
         self.g_new.grab_focus()
     def on_end_practise(self):
