@@ -48,10 +48,10 @@ class Teacher(abstract.LessonbasedTeacher):
         abstract.LessonbasedTeacher.__init__(self, exname, app,
             lesson_collection, lesson_file, config)
         self.lessonfileclass = lessonfile.ChordLessonfile
-        try: # the lessonfile might contain errors.
+        try: # try: because the file can have changed since startup
             self.parse_lessonfile()
         except dataparser.DataparserException, e:
-            self.m_app.m_ui.display_error_message('__init__'+str(e))
+            self.m_app.m_ui.display_exception_message(e, __file__)
     def new_question(self):
         """
         return 1 if the teacher has a question to ask
@@ -94,7 +94,7 @@ class Teacher(abstract.LessonbasedTeacher):
         return 1 if correct, None if not.
         Gui should not call this function if the question is already solved.
         """
-        v = self.m_P.get_music_as_notename_list()
+        v = self.m_P.get_music_as_notename_list('music')
         v.sort(mpd.compare_notenames)
         question_i = []
         for n in v:
@@ -172,20 +172,17 @@ class Gui(abstract.LessonbasedGui):
         self.add_random_transpose_gui()
         self.update_gui_after_lessonfile_change()
     def new_question(self, widget=None):
+        def exception_cleanup():
+            soundcard.synth.stop()
+            self.g_give_up.set_sensitive(False)
+            self.g_repeat.set_sensitive(False)
+            self.g_repeat_arpeggio.set_sensitive(False)
+            self.m_t.q_status = const.QSTATUS_NO
         # if we have no lessonfile, then we have no questions.
         if not self.m_t.m_P:
             return
         try:
             g = self.m_t.new_question()
-        except mpd.MpdException, e:
-            soundcard.synth.stop()
-            self.g_win.display_question_music_error_message(
-               self.m_t.m_P._idx, self.get_string('lessonfile'), e)
-            self.g_give_up.set_sensitive(False)
-            self.g_repeat.set_sensitive(False)
-            self.g_repeat_arpeggio.set_sensitive(False)
-            self.m_t.q_status = const.QSTATUS_NO
-        else:
             if g == Teacher.OK:
                 self.g_give_up.set_sensitive(True)
                 self.g_repeat.set_sensitive(True)
@@ -201,6 +198,15 @@ class Gui(abstract.LessonbasedGui):
                 self.g_chordtype_box.get_children()[0].grab_focus()
             elif g == Teacher.ERR_PICKY:
                 self.g_flashbar.flash(_("You have to solve this question first."))
+        except lessonfile.LessonfileException, e:
+            exception_cleanup()
+            # This exception will be raised if for example the music
+            # type for a question is invalid.
+            self.g_win.display_exception_message(e, __file__)
+        except mpd.MpdException, e:
+            exception_cleanup()
+            self.g_win.display_question_music_error_message(
+               self.m_t.m_P._idx, self.get_string('lessonfile'), e)
     def update_gui_after_lessonfile_change(self, *v):
         if self.m_t.m_P:
             self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
@@ -224,7 +230,7 @@ class Gui(abstract.LessonbasedGui):
         self.g_stacking_frame.set_sensitive(True)
         self.m_answer = []
         self.clear_stacking_frame()
-        v = self.m_t.m_P.get_music_as_notename_list()
+        v = self.m_t.m_P.get_music_as_notename_list('music')
         v.sort()
         for n in v:
             nn = mpd.MusicalPitch.new_from_notename(n)
@@ -243,6 +249,39 @@ class Gui(abstract.LessonbasedGui):
         self.g_stacking_frame.set_sensitive(True)
         self.g_redo.set_sensitive(False)
         self.show_music()
+    def on_chordtype_right_clicked(self, button, event, t):
+        if self.m_t.m_P and not self.m_t.m_P.header.enable_right_click:
+            self.g_flashbar.flash(_("Right click is not allowed for this lesson file."))
+            return
+        if self.m_t.q_status == const.QSTATUS_NO:
+            self.g_flashbar.flash(_("Click 'New chord' to begin."))
+            return
+        if self.m_t.q_status == const.QSTATUS_NEW:
+            self.g_flashbar.flash(_("You should try to guess before right-clicking."))
+            return
+        if not self.m_t.m_P.has_question():
+            return
+        try:
+            # We try first with the 'set' variable, as this is what is closest
+            if 'set' in self.m_t.m_P.get_question():
+                for question in self.m_t.m_P.m_questions:
+                    if question['set'] == self.m_t.m_P.get_question()['set'] \
+                            and question.get_cname() == t:
+                        self.m_t.m_P.play_question(question)
+                        return
+            #
+            for question in self.m_t.m_P.m_questions:
+                if question.get_cname() == self.m_t.m_P.get_cname():
+                    self.m_t.m_P.play_question(question)
+                    return
+        except lessonfile.LessonfileException, e:
+            # This exception will be raised if for example the music
+            # type for a question is invalid.
+            self.g_win.display_exception_message(e, __file__)
+        except mpd.MpdException, e:
+            # Invalid key variable or music code goes here.
+            self.g_win.display_question_music_error_message(
+                self.m_t.m_P._idx, self.get_string('lessonfile'), e)
     def on_chordtype_clicked(self, btn, t):
         if self.m_t.q_status == const.QSTATUS_NO:
             self.g_flashbar.flash(_("Click 'New chord' to begin."))
@@ -282,10 +321,10 @@ class Gui(abstract.LessonbasedGui):
         self.g_source.pack_start(md)
         md.show()
         md.display(r"\staff{ \clef %s < %s >}" % (
-                mpd.select_clef(self.m_t.m_P.get_music_as_notename_string()),
-                self.m_t.m_P.get_music_as_notename_string()), 20)
+                mpd.select_clef(self.m_t.m_P.get_music_as_notename_string('music')),
+                self.m_t.m_P.get_music_as_notename_string('music')), 20)
         # display the notenames on the buttons with octave info
-        v = self.m_t.m_P.get_music_as_notename_list()
+        v = self.m_t.m_P.get_music_as_notename_list('music')
         v.sort(mpd.compare_notenames)
         for n in v:
             b = gtk.Button(mpd.MusicalPitch.new_from_notename(n).get_user_octave_notename())
@@ -296,11 +335,12 @@ class Gui(abstract.LessonbasedGui):
         for x in self.g_chordtype_box.get_children():
             x.destroy()
         if self.m_t.m_P:
-            for t in self.m_t.m_P.m_chord_types.keys():
-                b = gtk.Button(self.m_t.m_P.m_chord_types[t])
-                b.set_data('chordtype', t)
+            for ctype, translated_type in self.m_t.m_P.m_chord_types.iteritems():
+                b = gtk.Button(translated_type)
+                b.set_data('chordtype', ctype)
                 self.g_chordtype_box.pack_start(b, False)
-                b.connect('clicked', self.on_chordtype_clicked, t)
+                b.connect('clicked', self.on_chordtype_clicked, ctype)
+                b.connect('button_release_event', self.on_chordtype_right_clicked, ctype)
                 b.show()
     def set_chordtype_frame_status_solved(self, t):
         for c in self.g_chordtype_box.get_children():
