@@ -15,6 +15,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+__exercise_data__ = {
+    'exercise_name': 'dictation',
+    'menu_path': '%s/%s' % (_("_Misc exercises"), _("_Dictation")),
+    'icon': 'graphics/dictation24.png',
+    'toolbar': 6,
+}
+import exercise_setup
+exercise_setup.register_exercise(__exercise_data__)
+
 import os
 
 import gtk, gnome
@@ -28,19 +37,21 @@ import configureoutput
 import dataparser
 
 class Teacher(abstract.LessonbasedTeacher):
+    exercise_data = __exercise_data__
     """
     The Teacher and Gui for dictation abuses q_status a little.
     QSTATUS_NEW mean that the lessonfile is ok.
     QSTATUS_NO mean that the question is corrupt and unusable. Other
                questions in the same file might be useable.
     """
-    def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
+    def __init__(self, exname, app, lesson_collection, lesson_file, config):
+        abstract.LessonbasedTeacher.__init__(self, exname, app,
+                lesson_collection, lesson_file, config)
         self.lessonfileclass = lessonfile.DictationLessonfile
         try:
             self.parse_lessonfile()
         except dataparser.DataparserException, e:
-            self.m_app.m_ui.display_error_message(str(e))
+            self.m_app.m_ui.display_exception_message(e, __file__)
         else:
             #to please abstract.LessonParser
             self.q_status = const.QSTATUS_NEW
@@ -61,40 +72,46 @@ class Gui(abstract.LessonbasedGui):
         # action_area #
         ###############
         self.g_partbox = gu.bHBox(self.practise_box, False)
-        b = gtk.Button(stock='gtk-go-back')
-        b.connect('clicked', self.select_previous)
-        b.show()
+        self.g_go_back = gtk.Button(stock='gtk-go-back')
+        self.g_go_back.connect('clicked', self.select_previous)
+        self.g_go_back.show()
         if configureoutput.WITH_GNOME:
-            b.get_children()[0].get_children()[0].get_children()[1].hide()
-        self.action_area.pack_start(b, False)
-        b = gtk.Button(stock='gtk-go-forward')
-        b.show()
-        b.connect('clicked', self.select_next)
+            self.g_go_back.get_children()[0].get_children()[0].get_children()[1].hide()
+        self.action_area.pack_start(self.g_go_back, False)
+        self.g_go_forward = b = gtk.Button(stock='gtk-go-forward')
+        self.g_go_forward.show()
+        self.g_go_forward.connect('clicked', self.select_next)
         if configureoutput.WITH_GNOME:
-            b.get_children()[0].get_children()[0].get_children()[1].hide()
-        self.action_area.pack_start(b, False)
+            self.g_go_forward.get_children()[0].get_children()[0].get_children()[1].hide()
+        self.action_area.pack_start(self.g_go_forward, False)
         self.g_play = gu.bButton(self.action_area, _("_Play the whole music"),
                                  self.play)
         self.g_show = gu.bButton(self.action_area, _("_Show"), self.show_answer)
         ##############
         # config_box #
         ##############
-        self.g_lessonfile_selector = widgets.SelectLessonfileWidget(
-              self.m_t, self.g_win, self.update_gui_after_lessonfile_change)
-        self.g_lessonfile_selector.show()
-        self.config_box.pack_start(self.g_lessonfile_selector)
+        self.add_select_lessonfile_gui()
         self.update_gui_after_lessonfile_change()
+    def exception_cleanup(self):
+        """ cleanup function after exception caught in select_previous
+        and select_next
+        """
+        soundcard.synth.stop()
+        self.m_t.q_status = const.QSTATUS_NO
+        self.g_play.set_sensitive(False)
+        self.g_show.set_sensitive(False)
+        self.g_music_displayer.clear()
     def select_previous(self, widget):
         self.m_t.m_P.select_previous()
         try:
             self.display_start_of_music()
         except mpd.MpdException, e:
+            self.exception_cleanup()
             self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.get_string('lessonfile'), e)
-            self.m_t.q_status = const.QSTATUS_NO
-            self.g_play.set_sensitive(False)
-            self.g_show.set_sensitive(False)
-            self.g_music_displayer.clear()
+                self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
+        except lessonfile.LessonfileException, e:
+            self.exception_cleanup()
+            self.g_win.display_exception_message(e, __file__)
         else:
             self.m_t.q_status = const.QSTATUS_NEW
             self.g_play.set_sensitive(True)
@@ -105,12 +122,12 @@ class Gui(abstract.LessonbasedGui):
         try:
             self.display_start_of_music()
         except mpd.MpdException, e:
+            self.exception_cleanup()
             self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.get_string('lessonfile'), e)
-            self.m_t.q_status = const.QSTATUS_NO
-            self.g_play.set_sensitive(False)
-            self.g_show.set_sensitive(False)
-            self.g_music_displayer.clear()
+                self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
+        except lessonfile.LessonfileException, e:
+            self.exception_cleanup()
+            self.g_win.display_exception_message(e, __file__)
         else:
             self.m_t.q_status = const.QSTATUS_NEW
             self.g_play.set_sensitive(True)
@@ -129,10 +146,9 @@ class Gui(abstract.LessonbasedGui):
             # if the user are fast, that the last question is still playing.
             soundcard.synth.stop()
             self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.get_string('lessonfile'), e)
+                self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
     def on_end_practise(self):
         self.m_t.end_practise()
-        self.update_gui_after_lessonfile_change()
     def show_answer(self, widget=None):
         # see Teacher docstring.
         if self.m_t.q_status != const.QSTATUS_NEW:
@@ -144,7 +160,7 @@ class Gui(abstract.LessonbasedGui):
                             self.get_int('config/feta_font_size=20'))
         except mpd.MpdException, e:
             self.g_win.display_question_music_error_message(
-                self.m_t.m_P._idx, self.get_string('lessonfile'), e)
+                self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
     def _update(self):
         """
         Updates the buttons above the action_area where you have
@@ -157,18 +173,18 @@ class Gui(abstract.LessonbasedGui):
                 track = mpd.music_to_track(self.m_t.m_P.get_music(),
                        self.get_int('config/preferred_instrument_velocity'),
                        start, end)
-                apply(track.prepend_bpm, self.m_t.m_P.get_tempo())
+                track.prepend_bpm(*self.m_t.m_P.get_tempo())
                 track.prepend_patch(0, self.get_int('config/preferred_instrument'))
                 soundcard.synth.play_track(track)
             except mpd.MpdException, e:
                 soundcard.synth.stop()
                 self.g_win.display_question_music_error_message(
-                   self.m_t.m_P._idx, self.get_string('lessonfile'), e)
+                   self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
         for i in self.g_partbox.get_children():
             i.destroy()
         # if the user selects a collection without lessonfiles, or if
         # the lessonfile was invalid, m_P could be None
-        if self.m_t.m_P:
+        if self.m_t.m_P and self.m_t.m_P.m_questions:
             self.g_question_title.set_text(self.m_t.m_P.get_name())
             v = self.m_t.m_P.get_breakpoints()
             if v == []:
@@ -204,13 +220,24 @@ class Gui(abstract.LessonbasedGui):
     def update_gui_after_lessonfile_change(self):
         self.m_t.q_status = const.QSTATUS_NEW
         if self.m_t.m_P:
+            if not self.m_t.m_P.m_questions:
+                self.g_win.display_error_message(_("The lesson file '%s' contains no questions.") % self.get_string('lessonfile'))
+                self.g_play.set_sensitive(False)
+                self.g_show.set_sensitive(False)
+                self.g_go_back.set_sensitive(False)
+                self.g_go_forward.set_sensitive(False)
+                self._update()
+                return
+            else:
+                self.g_go_forward.set_sensitive(True)
+                self.g_go_back.set_sensitive(True)
             self.m_t.m_P.select_first()
             self.action_area.set_sensitive(True)
             try:
                 self.display_start_of_music()
             except mpd.MpdException, e:
                 self.g_win.display_question_music_error_message(
-                    self.m_t.m_P._idx, self.get_string('lessonfile'), e)
+                    self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
                 self.m_t.q_status = const.QSTATUS_NO
                 self.g_play.set_sensitive(False)
                 self.g_show.set_sensitive(False)
