@@ -16,6 +16,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import gtk
+import gnome
 import soundcard
 import cfg
 
@@ -289,4 +290,16 @@ class SpinButtonRangeController(object):
         elif widget.get_value() > self.m_highest_value:
             self.g_spin_high.set_value(self.m_highest_value)
 
+def create_stock_menu_item(stock, txt, callback, ag, accel_key, accel_mod):
+    box = gtk.HBox()
+    box.set_spacing(gnome.ui.PAD_SMALL)
+    im = gtk.Image()
+    im.set_from_stock(stock, gtk.ICON_SIZE_MENU)
+    item = gtk.ImageMenuItem(txt)
+    item.set_image(im)
+    if accel_key != 0:
+        item.add_accelerator('activate', ag, accel_key, accel_mod, gtk.ACCEL_VISIBLE)
+    item.connect('activate', callback)
+    return item
+
 
