@@ -15,15 +15,26 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+__exercise_data__ = {
+    'exercise_name': 'harmonic-progression-dictation',
+    'menu_path': '%s/%s' % (_("_Misc exercises"), _("Harmonic _progression dictation")),
+    'icon': 'graphics/harmonicprogression24.png',
+    'toolbar': 13,
+}
+import exercise_setup
+exercise_setup.register_exercise(__exercise_data__)
+
 import gtk, gnome
 import abstract, idbyname, const, gu, statisticsviewer, widgets
 import soundcard, mpd, mpd.musicdisplayer
 import utils
-import dataparser
+import lessonfile
 
 class Teacher(idbyname.Teacher):
-    def __init__(self, exname, app):
-        idbyname.Teacher.__init__(self, exname, app)
+    exercise_data = __exercise_data__
+    def __init__(self, exname, app, lesson_collection, lesson_file, config):
+        idbyname.Teacher.__init__(self, exname, app,
+            lesson_collection, lesson_file, config)
     def play_question(self):
         if self.q_status == const.QSTATUS_NO:
             return
@@ -64,15 +75,13 @@ class Gui(abstract.LessonbasedGui):
         ##############
         # config_box #
         ##############
-        self.g_lessonfile_selector = widgets.SelectLessonfileWidget(
-           self.m_t, self.g_win, self.update_gui_after_lessonfile_change)
-        self.g_lessonfile_selector.show()
-        self.config_box.pack_start(self.g_lessonfile_selector)
+        self.add_select_lessonfile_gui()
         self.g_instrument_configurator \
             = widgets.InstrumentConfigurator(self.m_exname, 3)
         self.config_box.pack_start(self.g_instrument_configurator, False)
         self.g_instrument_configurator.show()
         # ------------------------------------------
+        self.add_random_transpose_gui()
         self._add_auto_new_question_gui(self.config_box)
         # ----------------------------------------------
 
@@ -105,24 +114,22 @@ class Gui(abstract.LessonbasedGui):
             self.g_music_displayer.display(self.m_t.m_P.get_music(),
                                self.get_int('config/feta_font_size=20'))
     def new_question(self, widget=None):
+        def exception_cleanup():
+            soundcard.synth.stop()
+            self.g_repeat.set_sensitive(False)
+            self.g_show.set_sensitive(False)
+            self.g_guess_answer.set_sensitive(False)
+            self.g_entry.set_text("")
+            self.g_music_displayer.clear()
         if not self.m_t.m_P:
             return
         # pop just in case there is something in the stack.
         self.g_flashbar.pop()
-        if self.m_t.new_question() == self.m_t.OK:
-            try:
+        try:
+            g = self.m_t.new_question()
+            if g == self.m_t.OK:
                 self.g_music_displayer.display(self.m_t.m_P.get_music(),
                             self.get_int('config/feta_font_size=20'), mpd.FIRST)
-            except mpd.MpdException, e:
-                soundcard.synth.stop()
-                self.g_win.display_question_music_error_message(
-                   self.m_t.m_P._idx, self.get_string('lessonfile'), e)
-                self.g_repeat.set_sensitive(False)
-                self.g_show.set_sensitive(False)
-                self.g_guess_answer.set_sensitive(False)
-                self.g_entry.set_text("")
-                self.g_music_displayer.clear()
-            else:
                 self.g_repeat.set_sensitive(True)
                 self.g_show.set_sensitive(True)
                 self.g_guess_answer.set_sensitive(True)
@@ -131,6 +138,13 @@ class Gui(abstract.LessonbasedGui):
                      not self.get_bool('config/picky_on_new_question'))
                 self.m_t.play_question()
                 self.g_entry.grab_focus()
+        except mpd.MpdException, e:
+            exception_cleanup()
+            self.g_win.display_question_music_error_message(
+               self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
+        except lessonfile.LessonfileException, e:
+            exception_cleanup()
+            self.g_win.display_exception_message(e, __file__)
     def give_up(self, widget=None):
         self.m_t.give_up()
         self.g_new.set_sensitive(True)
@@ -152,6 +166,7 @@ class Gui(abstract.LessonbasedGui):
     def update_gui_after_lessonfile_change(self):
         self.g_music_displayer.clear()
         if self.m_t.m_P:
+            self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
             self.g_new.set_sensitive(True)
         else:
             self.g_new.set_sensitive(False)
