@@ -137,7 +137,7 @@ class IntervalPianoWidget(PianoKeyboard):
         self.m_clicked_tones = []
     def mark(self, midi_int):
         x, y = self.midi_int_to_key(midi_int)
-        if not self.m_marks.has_key((x, y)):
+        if (x, y) not in self.m_marks:
             g = self.m_keyboard.add(gnome.canvas.CanvasGroup)
             g.connect('event', self.on_event, midi_int)
             self.m_marks[x, y] = g
@@ -158,7 +158,7 @@ class IntervalPianoWidget(PianoKeyboard):
         self.update_now()
     def unmark(self, midi_int):
         x, y = self.midi_int_to_key(midi_int)
-        if self.m_marks.has_key((x, y)):
+        if (x, y) in self.m_marks:
             self.m_marks[x, y].destroy()
             del self.m_marks[x, y]
         else:
@@ -387,7 +387,7 @@ class AbstractGuitarWidget(gnome.canvas.Canvas):
             if self.m_stringtuning[idx] <= note < self.m_stringtuning[idx] + len(self.m_fretdist):
                 self._set_mark(note - self.m_stringtuning[idx], idx)
     def _set_mark(self, x, y):
-        assert not self.m_mark_dict.has_key((x, y))
+        assert (x, y) not in self.m_mark_dict
         mark = self.m_guitar.add(gnome.canvas.CanvasGroup)
         self.m_mark_dict[(x, y)] = mark
         mark.add(gnome.canvas.CanvasEllipse, x1=-7, x2=7,
