@@ -24,12 +24,29 @@ except:
     import i18n
     i18n.setup_srcdir()
 
-class NoQuestionException(Exception):
-    pass
 class LessonfileException(Exception):
-    pass
+    def get_title(self):
+        return "LessonfileException"
 
-import re, types, os, sys
+class NoQuestionInFileException(LessonfileException):
+    """
+    Raised by find_random_question if the lesson file contains
+    no questions at all.
+    """
+    def __init__(self, lessonfilename):
+        self.m_filename = lessonfilename
+    def __str__(self):
+        return "The lesson file '%s' contains no questions." % self.m_filename
+
+class NoQuestionConfiguredException(LessonfileException):
+    """
+    This exception is raised by select_random_question if the user has
+    unselected all the questions available in the lesson file.
+    """
+    def __str__(self):
+        return "All questions are unselected. Select some questions from the config page."
+
+import re, os, sys
 import const
 import random
 import mpd
@@ -119,11 +136,12 @@ class _Header:
                            ('have_repeat_slowly_button', False),
                            ('have_repeat_arpeggio_button', False),
                            ('have_music_displayer', False),
+                           ('enable_right_click', True),
                            ):
-            if not self.m_headerdict.has_key(key):
+            if key not in self.m_headerdict:
                 self.m_headerdict[key] = value
     def __getattr__(self, name):
-        if self.m_headerdict.has_key(name):
+        if name in self.m_headerdict:
             return dataparser.get_translated_string(self.m_headerdict, name)
         raise NameError(name)
 
@@ -162,11 +180,13 @@ class LessonfileCommon(object):
         """
         count = 0
         available_question_idx = []
+        if not self.m_questions:
+            raise NoQuestionInFileException(self.m_filename)
         for i in range(len(self.m_questions)):
             if self.m_questions[i]['active']:
                 available_question_idx.append(i)
         if not available_question_idx:
-            raise NoQuestionException()
+            raise NoQuestionConfiguredException()
         while 1:
             count += 1
             self._idx = random.choice(available_question_idx)
@@ -178,7 +198,7 @@ class LessonfileCommon(object):
                 elif len(self.header.random_transpose) == 2:
                     self.header.random_transpose \
                         = ['semitones'] + self.header.random_transpose
-                if self.m_questions[self._idx].has_key('key'):
+                if 'key' in self.m_questions[self._idx]:
                     key = self.m_questions[self._idx]['key']
                 else:
                     key = "c \major"
@@ -244,7 +264,7 @@ class LessonfileCommon(object):
         """
         names = {}
         for question in self.m_questions:
-            if not names.has_key(question.get_cname()):
+            if question.get_cname() not in names:
                 names[question.get_cname()] = 1
                 yield question
     def get_unique_cnames(self):
@@ -392,7 +412,7 @@ class LessonfileCommon(object):
         elif question[varname].m_musictype in 'chord':
             self.play_question_musicformat_chord(question)
         else:
-            raise FIXME
+            raise LessonfileException("Unrecognised musictype '%s'" % question[varname].m_musictype)
     def play_question_musicformat_normal_satb(self, question):
         instrument = self.prepare_instrument_list(question)
         mpd.play_music(question.get_music(), self.get_tempo(),
@@ -412,10 +432,12 @@ class LessonfileCommon(object):
     def play_question_musicformat_chord(self, question):
         assert question['music'].m_musictype == 'chord'
         instrument = self.prepare_instrument_list(question)
+        assert len(instrument) in (2, 6)
         if len(instrument) == 2:
             mpd.play_music(question.get_music(), self.get_tempo(),
                        instrument[0], instrument[1])
-        elif len(instrument) == 6:
+        else:
+            assert len(instrument) == 6
             track = soundcard.Track()
             track.set_bpm(cfg.get_int('config/default_bpm'))#FIXME skulle dette vart tatt fra lesson file?
             nlist = self.get_music_as_notename_list(varname)
@@ -439,8 +461,6 @@ class LessonfileCommon(object):
                                    instrument[3])
             track.stop_note(len(nlist)-1, mpd.notename_to_int(nlist[-1]), instrument[5])
             soundcard.synth.play_track(track)
-        else:
-            raise "FIXME"
     def play_question_arpeggio(self, varname='music'):
         musictype = self.get_question()[varname].m_musictype
         if musictype == 'chord':
@@ -448,17 +468,19 @@ class LessonfileCommon(object):
         elif musictype == 'satb':
             self.play_question_musicformat_satb_arpeggio(varname)
         else:
-            raise FIXME#We need proper exception handling here
+            raise LessonfileException("\nUknown music type: '%s'" % self.get_question()[varname].m_musictype)
     def play_question_musicformat_chord_arpeggio(self, varname):
         """FIXME -- for completeness, should this function should take a question argument?
         """
         assert self.get_question()[varname].m_musictype == 'chord'
         instrument = self.prepare_instrument_list(self.get_question())
+        assert len(instrument) in (2, 6)
         if len(instrument) == 2:
             m = self.get_music_as_notename_string(varname)
             mpd.play_music(r"\staff{%s}" % m, self.get_tempo(),
                        instrument[0], instrument[1])
-        elif len(instrument) == 6:
+        else:
+            assert len(instrument) == 6
             track = soundcard.Track()
             track.set_bpm(cfg.get_int('config/default_bpm'))#FIXME skulle dette vart tatt fra lesson file?
             nlist = self.get_music_as_notename_list(varname)
@@ -474,8 +496,6 @@ class LessonfileCommon(object):
                                     instrument[3])
             track.note(4, len(nlist)-1, mpd.notename_to_int(nlist[-1]), instrument[5])
             soundcard.synth.play_track(track)
-        else:
-            raise "FIXME"
     def play_question_musicformat_satb_arpeggio(self):
         """FIXME -- for completeness, should this function should take a question argument?
         """
@@ -524,28 +544,30 @@ class LessonfileCommon(object):
         Use app default values if the variable is missing.
         Convert instrument names to integer values.
         """
-        if question.has_key('instrument'):
+        if 'instrument' in question:
             instrument = question['instrument']
-        elif self.m_globals.has_key('instrument'):
+        elif 'instrument' in self.m_globals:
             instrument = self.m_globals['instrument']
         else:
             instrument = [cfg.get_int('config/preferred_instrument'),
                           cfg.get_int('config/preferred_instrument_velocity')]
-        if type(instrument) in (types.UnicodeType, types.IntType):
+        if isinstance(instrument, (unicode, int)):
             instrument = [instrument,
                           cfg.get_int('config/preferred_instrument_velocity')]
+        assert len(instrument) in (2, 6)
         if len(instrument) == 2:
-            if type(instrument[0]) == types.UnicodeType:
+            if isinstance(instrument[0], unicode):
                 try:
                     instrument[0] = soundcard.find_midi_instrument_number(instrument[0])
                 except KeyError, e:
-                    print "Warning: Invalid instrument name in lesson file:", e
+                    print >> sys.stderr, "Warning: Invalid instrument name '%s' in lesson file:" % instrument[0], e
                     instrument[0] = cfg.get_int('config/preferred_instrument')
             if not (0 <= instrument[1] < 128):
+                print >> sys.stderr, "Warning: Adjusting instrument velocity since this value is invalid '%s'" % instrument[1]
                 instrument[1] = cfg.get_int('config/preferred_instrument_velocity')
         elif len(instrument) == 6:
             for x in (0, 2, 4):
-                if type(instrument[x]) == types.UnicodeType:
+                if isinstance(instrument[x], unicode):
                     try:
                         instrument[x] = soundcard.find_midi_instrument_number(instrument[x])
                     except KeyError, e:
@@ -553,8 +575,6 @@ class LessonfileCommon(object):
                         instrument[0] = cfg.get_int('config/preferred_instrument')
                 if not (0 <= instrument[x+1] < 128):
                     instrument[x+1] = cfg.get_int('config/preferred_instrument_velocity')
-        else:
-            raise "FIXME"
         return instrument
 
 
@@ -565,7 +585,7 @@ class DictationLessonfile(LessonfileCommon):
     def get_breakpoints(self):
         assert self._idx is not None
         r = []
-        if self.m_questions[self._idx].has_key('breakpoints'):
+        if 'breakpoints' in self.m_questions[self._idx]:
             r = self.m_questions[self._idx]['breakpoints']
             if not type(r) == type([]):
                 r = [r]
@@ -573,11 +593,11 @@ class DictationLessonfile(LessonfileCommon):
         return r
     def get_clue_end(self):
         assert self._idx is not None
-        if self.m_questions[self._idx].has_key('clue_end'):
-            return apply(Rat, self.m_questions[self._idx]['clue_end'])
+        if 'clue_end' in self.m_questions[self._idx]:
+            return Rat(*self.m_questions[self._idx]['clue_end'])
     def get_clue_music(self):
         assert self._idx is not None
-        if self.m_questions[self._idx].has_key('clue_music'):
+        if 'clue_music' in self.m_questions[self._idx]:
             return self.m_questions[self._idx]['clue_music']
     def select_previous(self):
         """
@@ -615,7 +635,7 @@ class IdByNameLessonfile(LessonfileCommon):
     def parse_file(self, filename):
         super(IdByNameLessonfile, self).parse_file(filename)
         for question in self.m_questions:
-            if not question.has_key('name'):
+            if 'name' not in question:
                 print >> sys.stderr, "IdByNameLessonfile.parse_file: discarding question in the lessonfile '%s'\nbecause of missing 'name' variable" % filename
                 continue
 
@@ -650,11 +670,11 @@ class ChordLessonfile(LessonfileCommon):
             self.m_chord_types[question.get_cname()] = question.get_name()
 
             # inversion
-            if question.has_key('inversion') \
+            if 'inversion' in question \
                     and question['inversion'] not in self.m_inversions:
                 self.m_inversions.append(question['inversion'])
             # toptone
-            if question.has_key('toptone') \
+            if 'toptone' in question \
                     and question['toptone'] not in self.m_toptones:
                 self.m_toptones.append(question['toptone'])
     def get_inversion(self):
@@ -664,7 +684,7 @@ class ChordLessonfile(LessonfileCommon):
         Return -1 if no inversion info is set in the question.
         """
         assert self._idx is not None
-        if self.m_questions[self._idx].has_key('inversion'):
+        if 'inversion' in self.m_questions[self._idx]:
              return self.m_questions[self._idx]['inversion']
         return -1
     def get_toptone(self):
@@ -673,7 +693,7 @@ class ChordLessonfile(LessonfileCommon):
         Return -1 if no toptone info is set in the question.
         """
         assert self._idx is not None
-        if self.m_questions[self._idx].has_key('toptone'):
+        if 'toptone' in self.m_questions[self._idx]:
             return self.m_questions[self._idx]['toptone']
         return -1
 
@@ -700,25 +720,25 @@ class LessonFileManager:
                     p.parse_file(self.get_complete_filename(collection, filename))
                 except dataparser.DataparserException, e:
                     self.m_invalid_files.append((collection, filename))
-                    print >> sys.stderr, "Discarding lessonfile '%s/%s' because the file contain errors:" % (collection, filename)
+                    print >> sys.stderr, "LessonFileManager.parse: Discarding lessonfile '%s/%s' because the file contain errors:" % (collection, filename)
                     print >> sys.stderr, str(e)
                     continue
                 c = p.header['content']
-                if type(c) in types.StringTypes:
+                if isinstance(c, basestring):
                     c = [c]
                 for u in c:
-                    if not self.m_db[collection].has_key(u):
+                    if u not in self.m_db[collection]:
                         self.m_db[collection][u] = []
-                    if p.header.has_key('title'):
+                    if 'title' in p.header:
                         title = p.header['title']
                     else:
                         title = ""
                     self.m_db[collection][u].append({'filename': filename,
                                                      'title': title}
                                                 )
-        for collection in self.m_db.keys():
-            for content in self.m_db[collection].keys():
-                self.m_db[collection][content].sort()
+        for collection in self.m_db.itervalues():
+            for content in collection:
+                collection[content].sort()
         self.m_htmldoc = """<html><body><p>This list is updated each time
                 you start Solfege. As you can see, Solfege need more
                 lessonfiles. <a href="lessonfiles.html">Write one!</a>"""
@@ -727,9 +747,9 @@ class LessonFileManager:
             for collection, filename in self.m_invalid_files:
                 self.m_htmldoc += "<li>%(filename)s in collection %(collection)s</li>" % {'collection': collection, 'filename': filename}
             self.m_htmldoc += "</ul>"
-        for collection in self.m_db.keys():
+        for collection in self.m_db:
             self.m_htmldoc = self.m_htmldoc + "<h1>collection: %s</h1>" % collection
-            for use in self.m_db[collection].keys():
+            for use in self.m_db[collection]:
                 self.m_htmldoc = self.m_htmldoc + "<h2>%s</h2><p>" % use
                 for d in self.m_db[collection][use]:
                     fn = d['filename']
@@ -751,7 +771,7 @@ class LessonFileManager:
         return os.path.expanduser(os.path.join(
          cfg.get_string('lessoncollections/%s' % catalog), fn))
     def get_filenames(self, collection, usetype):
-        if self.m_db[collection].has_key(usetype):
+        if usetype in self.m_db[collection]:
             v = []
             for d in self.m_db[collection][usetype]:
                 v.append(d['filename'])
@@ -759,7 +779,7 @@ class LessonFileManager:
         else:
             return []
     def get_info(self, collection, usetype):
-        if self.m_db[collection].has_key(usetype):
+        if usetype in self.m_db[collection]:
             return self.m_db[collection][usetype]
         else:
             return []
