@@ -125,7 +125,6 @@ class EditorLessonfile(object):
         self.m_filename = None
         self.m_changed = False
         self.header = lessonfile._Header({'content': ['chord']})
-        self._idx = None
         self.m_questions = [dataparser.Question()]
         self.m_questions[-1]['music'] = lessonfile.Music("", "chord")
         self.m_questions[-1]['name'] = ""
@@ -217,19 +216,31 @@ class MainWin(gtk.Window):
             self.set_title(self.m_P.m_filename)
         else:
             self.set_title("No file")
-        if self.m_P._idx is None:
-            self.g_navinfo.set_text("no question")
-            #FIXME does this ever happen? Should it?
-        else:
-            self.g_navinfo.set_text("question %i of %i" % (self.m_P._idx + 1,
-                    len(self.m_P.m_questions)))
-            self.g_question_name.set_text(self.m_P.m_questions[self.m_P._idx]['name'])
+        self.g_navinfo.set_text("question %i of %i" % (self.m_P._idx + 1,
+                len(self.m_P.m_questions)))
+        self.g_question_name.set_text(self.m_P.m_questions[self.m_P._idx]['name'])
     def load_file(self, filename):
         self.m_P = lessonfile.ChordLessonfile(filename, None)
         self.m_P.m_changed = False
         if self.m_P.m_questions:
-            self.m_P._idx = 0#FIXME what if lesson file has no questions.
+            self.m_P._idx = 0
             self.set_navinfo()
+        else:
+            # Do a little trick to make an empty question
+            self.m_P.m_questions = [dataparser.Question()]
+            self.m_P.m_questions[-1]['music'] = lessonfile.Music("", "chord")
+            self.m_P.m_questions[-1]['name'] = ""
+            self.m_P._idx = 0
+
+        for c in self.m_P.header.content:
+            if c not in ('id-by-name', 'chord', 'chord-voicing'):
+                dialog = gtk.MessageDialog(self, gtk.DIALOG_MODAL,
+                    gtk.MESSAGE_ERROR, gtk.BUTTONS_CLOSE,
+                    "Lesson file content '%s' is not supported yet. Cannot edit this file." % c)
+                dialog.run()
+                dialog.destroy()
+                self.m_P = EditorLessonfile()
+                break
         self.update_appwin()
     def file_open_cb(self, *v):
         if gtk_api == "2.0":
@@ -395,8 +406,6 @@ edit your hand written lesson files with this program.</p>
         Then call g_displayer.display to show the music.
         """
         assert self.m_P
-        if self.m_P._idx is None:
-            return
         self.m_chord_tones = {}
         for n in self.m_P.m_questions[self.m_P._idx]['music'].m_musicdata.split():
             p = mpd.MusicalPitch.new_from_notename(n)
@@ -540,7 +549,6 @@ def main(datadir):
             w = ItemFactoryMainWin(datadir)
         else:
             w = UIManagerMainWin(datadir)
-            #FIXME
         if len(sys.argv) == 2:
             w.load_file(sys.argv[1])
         w.show()
