@@ -20,7 +20,6 @@ __builtin__.app_running = True
 __builtin__.__exdata__ = []
 
 import sys, os, time, random
-import types
 
 if sys.version_info < (2, 3):
     print "********************************************************************"
@@ -173,7 +172,7 @@ import tracebackwindow
 
 sys.stderr = tracebackwindow.TracebackWindow()
 
-import const, string
+import const
 import app
 from htmlwidget import HtmlWidget
 import utils, history
@@ -237,7 +236,7 @@ class DocViewer(gtk.VBox):
     def on_anchor_track(self, url):
         if url:
             # remove newlines in url because it make the window resize
-            s = string.replace(url, "\n", "")
+            s = url.replace("\n", "")
             self.m_statusbar.pop(1)
             self.m_statusbar.push(1, s)
         else:
@@ -294,16 +293,29 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         ret = m.run()
         m.destroy()
         return ret == gtk.RESPONSE_YES
-    def display_error_message(self, msg, title=None):
+    def display_exception_message(self, exception, err_file=None):
+        """Call this function only inside an except clause."""
+        if err_file:
+            msg = _("Exception catched in %s:%i\n") % (err_file, sys.exc_info()[2].tb_lineno) + "\n"
+        else:
+            msg = ""
+        msg += str(exception)
         m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR,
                               gtk.BUTTONS_CLOSE, msg)
-        if title:
-            m.set_title(title)
+        m.set_title(sys.exc_info()[0].__name__)
         m.run()
         m.destroy()
-    def display_question_music_error_message(self, idx, lessonfile, exception):
-        self.display_error_message(_("Failed to parse the music for question number %(idx)i in '%(lf)s':\n%(ex)s")
-          % {'idx': idx, 'lf': lessonfile, 'ex': exception})
+    def display_error_message(self, msg, err_pos=None):
+        if err_pos:
+            msg = _("Error found in %s:\n") % err_pos + "\n" + msg
+        m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR,
+                              gtk.BUTTONS_CLOSE, msg)
+        m.run()
+        m.destroy()
+    def display_question_music_error_message(self, idx, lessonfile, exception, err_file=None):
+        """Call this function only inside an except clause."""
+        msg = _("Failed to parse the music for question number %(idx)i in '%(lf)s':\n%(ex)s") % {'idx': idx, 'lf': lessonfile, 'ex': exception}
+        self.display_exception_message(msg, err_file)
     def show_about_window(self, widget):
         #if not self.g_about_window:
         if 1:
@@ -355,7 +367,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         self.set_title("Solfege - " + self.box_dict[exname].get_pretty_name())
         self.m_history.add(href)
     def _show_docviewer(self):
-        if not self.box_dict.has_key('docviewer'):
+        if 'docviewer' not in self.box_dict:
             self.box_dict['docviewer'] = DocViewer(self.m_app.handle_href)
             self.main_box.pack_start(self.box_dict['docviewer'])
         if self.m_viewer and (self.m_viewer != 'docviewer'):
@@ -397,13 +409,13 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         self.m_app.handle_href(self.m_history.get_current()[0])
         self.m_history.unlock()
     def initialise_exercise(self, teacher):
-        assert not self.box_dict.has_key(teacher.m_exname)
+        assert teacher.m_exname not in self.box_dict
         n = utils.exercise_name_to_module_name(teacher.m_exname)
         self.box_dict[teacher.m_exname] = globals()[n].Gui(teacher, self)
         self.main_box.pack_start(self.box_dict[teacher.m_exname])
     def on_key_press_event(self, widget, event):
         if event.type == gtk.gdk.KEY_PRESS:
-            for s in self.m_key_bindings.keys():
+            for s in self.m_key_bindings:
                 if (event.state & (gtk.gdk.CONTROL_MASK|gtk.gdk.SHIFT_MASK), event.keyval) \
                          == utils.parse_key_string(self.get_string(s)):
                     self.m_key_bindings[s]()
@@ -434,17 +446,17 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         menu = gtk.Menu()
         for d in data:
             menuitem = gtk.ImageMenuItem(d['menu_path'].split('/')[1])
-            if d.has_key('icon'):
+            if 'icon' in d:
                 im = gtk.Image()
                 im.set_from_file(d['icon'])
                 im.set_from_pixbuf(im.get_pixbuf().scale_simple(16, 16, gtk.gdk.INTERP_TILES))
                 menuitem.set_image(im)
-            if d.has_key('exercise_config'):
+            if 'exercise_config' in d:
                 s = 'solfege:practise/%s/%s' % (d['exercise_name'], d['exercise_config'])
             else:
                 s = 'solfege:practise/%s' % d['exercise_name']
             menuitem.connect('activate', lambda o, self=self, s=s: self.m_app.handle_href(s))
-            if d.has_key('accel_key'):
+            if 'accel_key' in d:
                 menuitem.add_accelerator('activate', ag, d['accel_key'], d['accel_mods'], gtk.ACCEL_VISIBLE)
             menu.add(menuitem)
         return menu
@@ -473,7 +485,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         sections = []
         for rec in __exdata__:
             m, n = rec['menu_path'].split("/")
-            if not menus.has_key(m):
+            if m not in menus:
                 menus[m] = []
                 sections.append(m)
             menus[m].append(rec)
@@ -632,15 +644,15 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         tblist_unordered = []
         for e in __exdata__:
             exdict[e['exercise_name']] = e
-            if e.has_key('toolbar'):
-                if type(e['toolbar']) == types.BooleanType and e['toolbar'] == True:
+            if 'toolbar' in e:
+                if isinstance(e['toolbar'], bool) and e['toolbar'] == True:
                     tblist_unordered.append(e)
                 else:
                     tblist_ordered.append(e)
         tblist_ordered.sort(lambda a, b: cmp(a['toolbar'], b['toolbar']))
         for ex in tblist_ordered + tblist_unordered:
             im = gtk.Image()
-            if not ex.has_key('toolbar'):
+            if 'toolbar' not in ex:
                 continue
             im.set_from_file(ex['icon'])
             button = self.g_toolbar.append_item(ex['exercise_pretty_name'], ex['exercise_pretty_name'], None, im, None, None)
