@@ -17,19 +17,18 @@
 
 if __name__ == '__main__':
     import sys
-    #sys.path.insert(0, "/home/tom/pygtk19914/lib/python2.2/site-packages")
-
     import pygtk
     pygtk.require("2.0")
     import sys
     sys.path.append(".")
+    sys.path.append("src")
+    import i18n
+    i18n.setup_srcdir()
 
 import gtk
 import mpd, gu, cfg
 import gobject
 
-# FIXME This was not defined in gtk-types.defs yet
-INPUT_ERROR=-1
 DELAY1 = 500
 DELAY2 = 50
 
@@ -172,7 +171,7 @@ class nNotenameRangeController(NotenameRangeController, cfg.ConfigUtils):
 
 def _test():
     w = gtk.Window(gtk.WINDOW_TOPLEVEL)
-    w.set_size_request(100, 100)
+    #w.set_size_request(100, 100)
     vbox = gtk.VBox()
     w.add(vbox)
     #####
@@ -196,11 +195,8 @@ def _test():
     l.set_text("test<sup>3</sup>")
     vbox.pack_start(l)
     w.show_all()
-    w.connect('destroy', gtk.mainquit)
-    gtk.mainloop()
+    w.connect('delete_event', gtk.main_quit)
+    gtk.main()
 if __name__ == '__main__':
     sys.path.append(".")
-    #import src.i18n#, gettext, os, configureoutput
-    import gettext
-    x=gettext.install('solfege', 'share/locale', unicode=1)
     _test()
