@@ -15,10 +15,18 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+__exercise_data__ = {
+    'exercise_name': 'rhythm',
+    'menu_path': '%s/%s' % (_("_Rhythm"), _("Rh_ythm")),
+    'icon': 'graphics/rhythm24.png',
+    'toolbar': 11,
+}
+import exercise_setup
+exercise_setup.register_exercise(__exercise_data__)
+
 import gtk, gnome.ui
 import abstract, const, gu, mpd, soundcard
 import random, os
-import string
 import cfg
 
 RHYTHMS = ("c4", "c8 c8", "c16 c16 c16 c16", "c8 c16 c16",
@@ -31,11 +39,12 @@ RHYTHMS = ("c4", "c8 c8", "c16 c16 c16 c16", "c8 c16 c16",
 
 
 class Teacher(abstract.Teacher):
+    exercise_data = __exercise_data__
     OK = 0
     ERR_PICKY = 1
     ERR_NO_ELEMS = 2
-    def __init__(self, exname, app):
-        abstract.Teacher.__init__(self, exname, app)
+    def __init__(self, exname, app, config):
+        abstract.Teacher.__init__(self, exname, app, config)
     def new_question(self):
         """returns:
                Teacher.ERR_PICKY : if the question is not yet solved and the
