@@ -81,7 +81,7 @@ class SelectLessonfileWidget(gtk.VBox):
         self._cw = self.m_t.add_watch('lessoncollection', self._lessoncollectionwatch)
     def on_change_lessonfile_clicked(self, btn):
         i = self.find_current_selected_file_n()
-        dialog = FileSelectDialog(self.m_t.get_string('lessonfile'), self.m_t.get_string('lessoncollection'), self.m_t.m_exname, i)
+        dialog = FileSelectDialog(self.m_t.get_string('lessonfile'), self.m_t.get_string('lessoncollection'), self.m_t.m_exname, i, self.m_ui.m_app.lessonfile_manager)
         response = dialog.run()
         dialog.hide()
         if response == gtk.RESPONSE_OK:
@@ -151,8 +151,7 @@ class SelectLessonfileWidget(gtk.VBox):
         """Find what number the currently active lesson file has.
         """
         i = 0
-        m = lessonfile.LessonFileManager()
-        for d in m.get_info(self.m_t.get_string('lessoncollection'), self.m_t.m_exname):
+        for d in self.m_ui.m_app.lessonfile_manager.get_info(self.m_t.get_string('lessoncollection'), self.m_t.m_exname):
             if d['filename'] == self.m_t.get_string('lessonfile'):
                 return i
             i += 1
@@ -160,12 +159,13 @@ class SelectLessonfileWidget(gtk.VBox):
 
 
 class FileSelectDialog(gtk.Dialog):
-    def __init__(self, lessonfile, collection, exname, current_filenum):
+    def __init__(self, lessonfile, collection, exname, current_filenum, lessonfile_manager):
         gtk.Dialog.__init__(self, _("Select lesson file"), None, 0, 
               (
                gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
                gtk.STOCK_OK, gtk.RESPONSE_OK,
                ))
+        self.m_lessonfile_manager = lessonfile_manager
         self.m_collection = collection
         self.m_exname = exname
         # select collection
@@ -219,11 +219,10 @@ class FileSelectDialog(gtk.Dialog):
         self.action_area.get_children()[0].set_sensitive(self.m_can_ok)
     def create_liststore_dict(self):
         self.m_liststore_dict ={}
-        m = lessonfile.LessonFileManager()
         for collection in cfg.get_string('config/lessoncollections').split():
             self.m_liststore_dict[collection] = \
                  gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING)
-            for d in m.get_info(collection, self.m_exname):
+            for d in self.m_lessonfile_manager.get_info(collection, self.m_exname):
                 iter = self.m_liststore_dict[collection].append()
                 if not d['title']:
                     d['title'] = "Warning: '%s' has no title." % d['filename']
