@@ -30,6 +30,7 @@ import dataparser
 import mpd
 import utils
 import const
+import soundcard
 
 class Teacher(abstract.LessonbasedTeacher):
     exercise_data = __exercise_data__
@@ -42,7 +43,7 @@ class Teacher(abstract.LessonbasedTeacher):
         try: # the lesson file might contain errors.
             self.parse_lessonfile()
         except dataparser.DataparserException, e:
-            self.m_app.m_ui.display_error_message(str(e))
+            self.m_app.m_ui.display_exception_message(e, __file__)
     def new_question(self):
         # TODO This function is very similar to the one in src/idbyname.py
         self.q_status = const.QSTATUS_NO
@@ -51,7 +52,7 @@ class Teacher(abstract.LessonbasedTeacher):
             self.m_P.select_random_question()
             self.q_status = const.QSTATUS_NEW
             return self.OK
-        except lessonfile.NoQuestionException:
+        except lessonfile.NoQuestionConfiguredException:
             return self.ERR_NO_QUESTION
 
 class Gui(abstract.LessonbasedGui):
@@ -75,25 +76,45 @@ class Gui(abstract.LessonbasedGui):
         self.show_all()
         self.update_gui_after_lessonfile_change()
     def new_question(self, widget):
+        def exception_cleanup():
+            soundcard.synth.stop()
+            self.g_music_displayer.clear()
+            self.g_repeat.set_sensitive(False)
+            self.g_repeat_arpeggio.set_sensitive(False)
+            self.g_play_answer.set_sensitive(False)
         if self.m_t.m_P.header.have_music_displayer:
             self.g_music_displayer.clear()
         try:
             g = self.m_t.new_question()
+            self.g_music_displayer.display(self.m_t.m_P.get_music(), 20)
+            self.g_question.set_text(self.m_t.m_P.get_question()['question_text'])
+            self.m_t.m_P.play_question()
+            self.g_repeat.set_sensitive(True)
+            self.g_repeat_arpeggio.set_sensitive(True)
+            self.g_play_answer.set_sensitive(True)
         except lessonfile.LessonfileException, e:
-            self.g_win.display_error_message("In the file %s: %s" % (self.m_t.m_P.m_filename, str(e)))
-            return
-        self.g_music_displayer.display(self.m_t.m_P.get_music(), 20)
-        self.g_question.set_text(self.m_t.m_P.get_question()['question_text'])
-        self.m_t.m_P.play_question()
-        self.g_repeat.set_sensitive(True)
-        self.g_repeat_arpeggio.set_sensitive(True)
-        self.g_play_answer.set_sensitive(True)
+            exception_cleanup()
+            self.g_win.display_exception_message(e, __file__)
+        except mpd.MpdException, e:
+            # Invalid key variable or music code goes here.
+            exception_cleanup()
+            self.g_win.display_question_music_error_message(
+                self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
     def repeat_question(self, widget):
         self.m_t.m_P.play_question()
     def repeat_question_arpeggio(self, widget):
         self.m_t.m_P.play_question_arpeggio()
     def hear_answer(self, widget):
-        mpd.play_music(self.m_t.m_P.prepare_music_from_string(self.m_t.m_P.get_question(), 'answer'), 120, 0, 100)
+        try:
+            mpd.play_music(self.m_t.m_P.prepare_music_from_string(self.m_t.m_P.get_question(), 'answer'), 120, 0, 100)
+        except lessonfile.LessonfileException, e:
+            soundcard.synth.stop()
+            self.g_win.display_exception_message(e, __file__)
+        except mpd.MpdException, e:
+            # Invalid key variable or music code goes here.
+            soundcard.synth.stop()
+            self.g_win.display_question_music_error_message(
+                self.m_t.m_P._idx, self.get_string('lessonfile'), e, __file__)
     def update_gui_after_lessonfile_change(self):
         if self.m_t.m_P:
             self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
@@ -104,5 +125,9 @@ class Gui(abstract.LessonbasedGui):
             self.g_repeat.set_sensitive(False)
             self.g_repeat_arpeggio.set_sensitive(False)
             self.g_play_answer.set_sensitive(False)
+        else:
+            self.g_repeat.set_sensitive(False)
+            self.g_repeat_arpeggio.set_sensitive(False)
+            self.g_play_answer.set_sensitive(False)
         self.g_new.set_sensitive(bool(self.m_t.m_P))
         self.g_win.set_title("Solfege - " + self.get_pretty_name())
