@@ -15,16 +15,27 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+__exercise_data__ = {
+    'exercise_name': 'sing-chord',
+    'menu_path': '%s/%s' % (_("_Chords"), _("Sin_g chord")),
+    'icon': 'graphics/singchord24.png',
+    'toolbar': 10,
+}
+import exercise_setup
+exercise_setup.register_exercise(__exercise_data__)
+
 import gtk, gnome
 import gu, const, soundcard, mpd, mpd.musicdisplayer, abstract
-import lessonfile, string
+import lessonfile
 import widgets
 import utils
 import dataparser
 
 class Teacher(abstract.LessonbasedTeacher):
-    def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
+    exercise_data = __exercise_data__
+    def __init__(self, exname, app, lesson_collection, lesson_file, config):
+        abstract.LessonbasedTeacher.__init__(self, exname, app,
+            lesson_collection, lesson_file, config)
         self.lessonfileclass = lessonfile.SingChordLessonfile
         try: # the lessonfile might contain errors.
             self.parse_lessonfile()
@@ -61,28 +72,30 @@ class Gui(abstract.LessonbasedGui):
         ##############
         # config_box #
         ##############
-        self.g_lessonfile_selector = widgets.SelectLessonfileWidget(
-             self.m_t, self.g_win, self.update_gui_after_lessonfile_change)
-        self.g_lessonfile_selector.show()
-        self.config_box.pack_start(self.g_lessonfile_selector)
+        self.add_select_lessonfile_gui()
+        self.add_random_transpose_gui()
         self.update_gui_after_lessonfile_change()
     def new_question(self, widget=None):
-        # if we have no lessonfile, then we have no questions.
-        if not self.m_t.m_P:
-            return
+        def exception_cleanup():
+            soundcard.synth.stop()
+            self.g_play_answer.set_sensitive(False)
+            self.g_music_displayer.clear()
         try:
             self.m_t.new_question()
-        except mpd.MpdException, e:
-            # since we could not play the new question, it is possible,
-            # if the user are fast, that the last question is still playing.
-            soundcard.synth.stop()
-            self.g_win.display_error_message(
-                self.m_t.m_P._idx, self.get_string('lessonfile'), e)
-        else:
             fontsize = self.get_int('config/feta_font_size=20')
             self.g_music_displayer.display(self.m_t.m_P.get_music(), fontsize)
             self.g_play_answer.set_sensitive(True)
             self.m_t.play_440hz()
+        except mpd.MpdException, e:
+            # since we could not play the new question, it is possible,
+            # if the user are fast, that the last question is still playing.
+            exception_cleanup()
+            self.g_win.display_question_music_error_message(
+                self.m_t.m_P._idx, self.get_string('lessonfile'), e)
+        except lessonfile.LessonfileException, e:
+            # caused by for example invalid musicformat
+            exception_cleanup()
+            self.g_win.display_exception_message(e, __file__)
     def on_start_practise(self):
         # if we have not m_P, then parsing of the lessonfile failed,
         # and then we have no questions.
@@ -98,6 +111,7 @@ class Gui(abstract.LessonbasedGui):
     def update_gui_after_lessonfile_change(self):
         self.g_music_displayer.clear(2)
         if self.m_t.m_P:
+            self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
             self.g_new.set_sensitive(True)
         else:
             self.g_new.set_sensitive(False)
