@@ -19,6 +19,7 @@ import re
 import sys
 import gtk
 import cfg
+import gu
 
 class HarmonicProgressionLabel(gtk.HBox):
     """
@@ -151,10 +152,10 @@ class QuestionNameButtonTable(AbstractQuestionNameTable):
         (c locale) name.
         return the button created.
         """
-        if question.has_key('newline') and question['newline']:
+        if 'newline' in question and question['newline']:
             self.newline()
         b = gtk.Button()
-        if self.m_button_dict.has_key(question.get_cname()):
+        if question.get_cname() in self.m_button_dict:
             print >> sys.stderr, "Warning: The lessonfile contain several questions with the same name:", question.get_cname()
             print >> sys.stderr, "         This is a bug in the lesson file."
         self.m_button_dict[question.get_cname()] = b
@@ -187,10 +188,10 @@ class QuestionNameCheckButtonTable(AbstractQuestionNameTable):
         (c locale) name.
         return the button created.
         """
-        if question.has_key('newline') and question['newline']:
+        if 'newline' in question and question['newline']:
             self.newline()
         b = gtk.CheckButton()
-        if self.m_button_dict.has_key(question.get_cname()):
+        if question.get_cname() in self.m_button_dict:
             print >> sys.stderr, "Warning: The lessonfile contain several questions with the same name:", question.get_cname()
             print >> sys.stderr, "         Things will not work as normal after this."
         self.m_button_dict[question.get_cname()] = b
@@ -221,3 +222,97 @@ class QuestionNameCheckButtonTable(AbstractQuestionNameTable):
     def select_all(self):
         for button in self.m_button_dict.values():
             button.set_active(True)
+
+class RandomTransposeDialog(gtk.Dialog):
+    def __init__(self, initial_value, parent):
+        gtk.Dialog.__init__(self, _("Set transposition"), parent, 0, 
+           (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
+            gtk.STOCK_OK, gtk.RESPONSE_OK,
+            ))
+        dlg_vbox = gu.hig_dlg_vbox()
+        self.vbox.pack_start(dlg_vbox)
+        xbox, vbox = gu.hig_category_vbox(_("Select how to do random transposition"))
+        dlg_vbox.pack_start(xbox)
+        label = gtk.Label(_("""You can read about the different types of transposition in the lesson file documentation available on the Help menu."""))
+        label.set_line_wrap(True)
+        vbox.pack_start(label)
+        sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
+        self.m_buttons = {}
+        self.m_spins = {}
+        self.m_buttons['no'] = b1 = gtk.RadioButton(None, _("No"))
+        self.m_spins['no'] = []
+        vbox.pack_start(b1)
+        self.m_buttons['yes'] = b2 = gtk.RadioButton(b1, _("Yes"))
+        self.m_spins['yes'] = []
+        vbox.pack_start(b2)
+
+        self.m_buttons['accidentals'] = gtk.RadioButton(b1, "accidentals")
+        hbox = gu.bHBox(vbox)
+        hbox.pack_start(self.m_buttons['accidentals'])
+        self.m_spins['accidentals'] = [
+            gtk.SpinButton(gtk.Adjustment(0, -7, 7, 1, 1, 1), 0.0, 0),
+            gtk.SpinButton(gtk.Adjustment(0, -7, 7, 1, 1, 1), 0.0, 0)]
+        hbox.pack_start(self.m_spins['accidentals'][0])
+        hbox.pack_start(self.m_spins['accidentals'][1])
+        gu.SpinButtonRangeController(self.m_spins['accidentals'][0],
+                                     self.m_spins['accidentals'][1],
+                                     -7, 7)
+
+        self.m_buttons['key'] = gtk.RadioButton(b1, "key")
+        hbox = gu.bHBox(vbox)
+        hbox.pack_start(self.m_buttons['key'])
+        self.m_spins['key'] = [
+            gtk.SpinButton(gtk.Adjustment(0, -10, 10, 1, 1, 1), 0.0, 0),
+            gtk.SpinButton(gtk.Adjustment(0, -10, 10, 1, 1, 1), 0.0, 0)]
+        hbox.pack_start(self.m_spins['key'][0])
+        hbox.pack_start(self.m_spins['key'][1])
+        gu.SpinButtonRangeController(self.m_spins['key'][0],
+                                     self.m_spins['key'][1],
+                                     -10, 10)
+
+        self.m_buttons['semitones'] = gtk.RadioButton(b1, "semitones")
+        hbox = gu.bHBox(vbox)
+        hbox.pack_start(self.m_buttons['semitones'])
+        self.m_spins['semitones'] = [
+            gtk.SpinButton(gtk.Adjustment(0, -100, 100, 1, 1, 1), 0.0, 0),
+            gtk.SpinButton(gtk.Adjustment(0, -100, 100, 1, 1, 1), 0.0, 0)]
+        hbox.pack_start(self.m_spins['semitones'][0])
+        hbox.pack_start(self.m_spins['semitones'][1])
+        gu.SpinButtonRangeController(self.m_spins['semitones'][0],
+                                     self.m_spins['semitones'][1],
+                                     -100, 100)
+        for n, w in self.m_buttons.items():
+            sizegroup.add_widget(w)
+            for ww in self.m_spins[n]:
+                ww.set_sensitive(False)
+            w.connect('clicked', self.on_spins_clicked, n)
+        if initial_value == False:
+            k = 'no'
+        elif initial_value == True:
+            k = 'yes'
+        else:
+            k = initial_value[0]
+        self.m_buttons[k].set_active(True)
+        if k in ('accidentals', 'key', 'semitones'):
+            t, v1, v2 = initial_value
+            # FIXME Because of the RangeController, we have to do this
+            # twice to be sure both values are set properly.
+            self.m_spins[t][1].set_value(v2)
+            self.m_spins[t][0].set_value(v1)
+            self.m_spins[t][1].set_value(v2)
+            self.m_spins[t][0].set_value(v1)
+        self.show_all()
+    def on_spins_clicked(self, w, n):
+        for w in self.m_spins[n]:
+            w.set_sensitive(self.m_buttons[n].get_active())
+    def get_value(self):
+        for n, btn in self.m_buttons.items():
+            if btn.get_active():
+                s = n
+        if s == 'yes':
+            return True
+        elif s == 'no':
+            return False
+        return [s, self.m_spins[s][0].get_value_as_int(), self.m_spins[s][1].get_value_as_int()]
+
+
