@@ -26,11 +26,10 @@ except:
 
 
 import gtk
-import string, re, math
+import re, math
 import mpd
 import const
 import random
-import types
 import soundcard, cfg
 
 def play_tone(midi_int):
@@ -52,8 +51,8 @@ def int_to_intervalname(i, shortname=None, updown=None):
 
 
 def filter_intervals_within_range(lowest, highest, irange):
-    assert type(lowest) in types.StringTypes
-    assert type(highest) in types.StringTypes
+    assert isinstance(lowest, basestring)
+    assert isinstance(highest, basestring)
     lowest = mpd.notename_to_int(lowest)
     highest = mpd.notename_to_int(highest)
     i = highest - lowest
@@ -66,15 +65,16 @@ def random_interval(tonika, lowest, highest, irange):
     """
     if isinstance(tonika, mpd.MusicalPitch):
         tonika = tonika.semitone_pitch()
-    assert type(tonika) == types.IntType
+    assert isinstance(tonika, int)
     assert type(lowest) == type(highest)
-    if type(lowest) in types.StringTypes:
+    if isinstance(lowest, basestring):
         lowest = mpd.notename_to_int(lowest)
-    if type(highest) in types.StringTypes:
+    if isinstance(highest, basestring):
         highest = mpd.notename_to_int(highest)
-    assert type(lowest) == type(highest) == types.IntType
+    assert isinstance(lowest, int)
+    assert isinstance(highest, int)
     assert lowest <= highest
-    assert type(irange) == types.ListType
+    assert isinstance(irange, list)
     v = []
     for i in irange:
         if lowest <= tonika + i <= highest:
@@ -96,13 +96,14 @@ def random_tonika_and_interval(lowest, highest, irange):
              second up, -2 is major second down
     """
     assert type(lowest) == type(highest)
-    if type(lowest) in types.StringTypes:
+    if isinstance(lowest, basestring):
         lowest = mpd.notename_to_int(lowest)
-    if type(highest) == types.StringTypes:
+    if isinstance(highest, basestring):
         highest = mpd.notename_to_int(highest)
-    assert type(lowest) == type(highest) == types.IntType
+    assert isinstance(lowest, int)
+    assert isinstance(highest, int)
     assert lowest <= highest
-    assert type(irange) == types.ListType
+    assert isinstance(irange, list)
     # first we find out what is the largest interval we can have
     i = highest - lowest
     # then filter irange to only use intervals <= i
@@ -127,8 +128,8 @@ def adjust_low_high_to_irange(lowest, highest, irange):
              second up, -2 is major second down
     return tuple with two integers
     """
-    assert type(lowest) in types.StringTypes
-    assert type(highest) in types.StringTypes
+    assert isinstance(lowest, basestring)
+    assert isinstance(highest, basestring)
     L = mpd.notename_to_int(lowest)
     H = mpd.notename_to_int(highest)
     # find the largest interval that can be asked for
@@ -164,16 +165,13 @@ def parse_url(s):
         return None, None, s, None, None, None, {}
     D = {}
     if m.group('config'):
-        V = string.split(m.group('config'), ";")
+        V = m.group('config').split(";")
         for e in V:
-            n, v = string.split(e, "=")
-            n = string.strip(n)
-            v = string.strip(v)
-            #if v[0] in string.letters:
-            D[string.strip(n)] = v#eval("\""+v+"\"")
-            #else:
-            #    D[string.strip(n)] = eval(v)
-    for k in D.keys():
+            n, v = e.split("=")
+            n = n.strip(n)
+            v = v.strip(v)
+            D[n.strip()] = v
+    for k in D:
         D[k] = un_escape_url_string(D[k])
     return m.group('protocol'), m.group('action'), m.group('fn'), \
            m.group('anchor'), m.group('collection'), m.group('lessonfile'), D
@@ -219,7 +217,7 @@ def freq_to_notename_cent(freq):
 
 def exercise_name_to_module_name(name):
     # it is just plain luck that this works...
-    return string.replace(name, '-', '')
+    return name.replace('-', '')
 
 def compare_version_strings(A, B):
     """
@@ -235,8 +233,8 @@ def compare_version_strings(A, B):
         return -1
     elif B == "":
         return 1
-    av = map(lambda s: int(s), string.split(A, "."))
-    bv = map(lambda s: int(s), string.split(B, "."))
+    av = map(lambda s: int(s), A.split("."))
+    bv = map(lambda s: int(s), B.split("."))
     x = 0
     while len(av) > x < len(bv):
         if av[x] > bv[x]:
